// Main JavaScript file for Points Club

// Wait for DOM to be fully loaded
document.addEventListener('DOMContentLoaded', function() {
    // Initialize tooltips
    initTooltips();
    
    // Initialize form validations
    initFormValidations();
    
    // Add animation effects
    addAnimationEffects();
});

// Initialize tooltips
function initTooltips() {
    const tooltips = document.querySelectorAll('[data-tooltip]');
    
    tooltips.forEach(tooltip => {
        tooltip.addEventListener('mouseenter', function() {
            const tooltipText = this.getAttribute('data-tooltip');
            const tooltipEl = document.createElement('div');
            tooltipEl.className = 'tooltip';
            tooltipEl.textContent = tooltipText;
            
            document.body.appendChild(tooltipEl);
            
            const rect = this.getBoundingClientRect();
            tooltipEl.style.top = rect.top - tooltipEl.offsetHeight - 10 + 'px';
            tooltipEl.style.left = rect.left + (rect.width / 2) - (tooltipEl.offsetWidth / 2) + 'px';
            tooltipEl.style.opacity = '1';
        });
        
        tooltip.addEventListener('mouseleave', function() {
            const tooltipEl = document.querySelector('.tooltip');
            if (tooltipEl) {
                tooltipEl.remove();
            }
        });
    });
}

// Initialize form validations
function initFormValidations() {
    const forms = document.querySelectorAll('form');
    
    forms.forEach(form => {
        form.addEventListener('submit', function(e) {
            const requiredFields = form.querySelectorAll('[required]');
            let isValid = true;
            
            requiredFields.forEach(field => {
                if (!field.value.trim()) {
                    isValid = false;
                    highlightInvalidField(field);
                } else {
                    removeInvalidHighlight(field);
                }
            });
            
            // Email validation
            const emailFields = form.querySelectorAll('input[type="email"]');
            emailFields.forEach(field => {
                if (field.value && !isValidEmail(field.value)) {
                    isValid = false;
                    highlightInvalidField(field);
                }
            });
            
            // Password matching validation
            const passwordField = form.querySelector('input[name="password"]');
            const confirmPasswordField = form.querySelector('input[name="confirm_password"]');
            
            if (passwordField && confirmPasswordField) {
                if (passwordField.value !== confirmPasswordField.value) {
                    isValid = false;
                    highlightInvalidField(confirmPasswordField);
                    showValidationMessage(confirmPasswordField, 'Passwords do not match');
                }
            }
            
            if (!isValid) {
                e.preventDefault();
            }
        });
    });
}

// Validate email format
function isValidEmail(email) {
    const re = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return re.test(email);
}

// Highlight invalid field
function highlightInvalidField(field) {
    field.classList.add('invalid');
    
    field.addEventListener('input', function() {
        removeInvalidHighlight(field);
    }, { once: true });
}

// Remove invalid highlight
function removeInvalidHighlight(field) {
    field.classList.remove('invalid');
    
    // Remove any validation message
    const validationMessage = field.parentNode.querySelector('.validation-message');
    if (validationMessage) {
        validationMessage.remove();
    }
}

// Show validation message
function showValidationMessage(field, message) {
    // Remove existing message if any
    const existingMessage = field.parentNode.querySelector('.validation-message');
    if (existingMessage) {
        existingMessage.remove();
    }
    
    // Create and append new message
    const messageEl = document.createElement('div');
    messageEl.className = 'validation-message';
    messageEl.textContent = message;
    field.parentNode.appendChild(messageEl);
}

// Add animation effects
function addAnimationEffects() {
    // Fade in sections
    const sections = document.querySelectorAll('section');
    sections.forEach((section, index) => {
        section.style.opacity = '0';
        section.style.transform = 'translateY(20px)';
        section.style.transition = 'opacity 0.5s ease, transform 0.5s ease';
        
        setTimeout(() => {
            section.style.opacity = '1';
            section.style.transform = 'translateY(0)';
        }, 100 * index);
    });
    
    // Add hover effects to buttons
    const buttons = document.querySelectorAll('.btn');
    buttons.forEach(button => {
        button.addEventListener('mouseenter', function() {
            this.style.transform = 'translateY(-2px)';
            this.style.boxShadow = '0 4px 8px rgba(0, 0, 0, 0.1)';
        });
        
        button.addEventListener('mouseleave', function() {
            this.style.transform = 'translateY(0)';
            this.style.boxShadow = 'none';
        });
    });
    
    // Add pulse effect to stat values
    const statValues = document.querySelectorAll('.stat-value');
    statValues.forEach(value => {
        value.classList.add('pulse-animation');
    });
}

// Calculate total cost based on points (for buy points page)
if (document.getElementById('points')) {
    document.getElementById('points').addEventListener('input', function() {
        const points = parseInt(this.value) || 0;
        const pointCostElement = document.querySelector('.point-cost .cost');
        
        if (pointCostElement) {
            const pointCostText = pointCostElement.textContent;
            const pointCost = parseFloat(pointCostText.replace('$', '')) || 1.00;
            const total = (points * pointCost).toFixed(2);
            
            document.getElementById('total-amount').textContent = total;
        }
    });
}

// Toggle payment method forms (for payment page)
const paymentMethodRadios = document.querySelectorAll('input[name="payment_method"]');
if (paymentMethodRadios.length > 0) {
    paymentMethodRadios.forEach(function(radio) {
        radio.addEventListener('change', function() {
            const paypalForm = document.getElementById('paypal_form');
            const creditCardForm = document.getElementById('credit_card_form');
            
            if (paypalForm && creditCardForm) {
                paypalForm.style.display = 'none';
                creditCardForm.style.display = 'none';
                
                if (this.value === 'paypal') {
                    paypalForm.style.display = 'block';
                } else if (this.value === 'credit_card') {
                    creditCardForm.style.display = 'block';
                }
            }
        });
    });
}

// Toggle cashout form (for transactions page)
const cashoutBtn = document.getElementById('cashout-btn');
const cancelCashoutBtn = document.getElementById('cancel-cashout');
const cashoutForm = document.getElementById('cashout-form');

if (cashoutBtn && cancelCashoutBtn && cashoutForm) {
    cashoutBtn.addEventListener('click', function() {
        cashoutForm.style.display = 'block';
    });
    
    cancelCashoutBtn.addEventListener('click', function() {
        cashoutForm.style.display = 'none';
    });
}

// Add CSS animations
const style = document.createElement('style');
style.textContent = `
    @keyframes pulse {
        0% { transform: scale(1); }
        50% { transform: scale(1.05); }
        100% { transform: scale(1); }
    }
    
    .pulse-animation {
        animation: pulse 2s infinite;
    }
    
    .tooltip {
        position: absolute;
        background-color: #333;
        color: #fff;
        padding: 5px 10px;
        border-radius: 4px;
        font-size: 14px;
        z-index: 100;
        opacity: 0;
        transition: opacity 0.3s;
    }
    
    .tooltip::after {
        content: '';
        position: absolute;
        top: 100%;
        left: 50%;
        margin-left: -5px;
        border-width: 5px;
        border-style: solid;
        border-color: #333 transparent transparent transparent;
    }
    
    .invalid {
        border-color: #f44336 !important;
        box-shadow: 0 0 0 2px rgba(244, 67, 54, 0.2) !important;
    }
    
    .validation-message {
        color: #f44336;
        font-size: 14px;
        margin-top: 5px;
    }
`;

document.head.appendChild(style);
