-- Points Club Database Schema
-- Database: pointy_db
-- Table prefix: pc_

-- Drop existing tables if they exist to prevent errors
DROP TABLE IF EXISTS `pc_transactions`;
DROP TABLE IF EXISTS `pc_positions`;
DROP TABLE IF EXISTS `pc_pyramids`;
DROP TABLE IF EXISTS `pc_user_sessions`;
DROP TABLE IF EXISTS `pc_users`;
DROP TABLE IF EXISTS `pc_settings`;

-- Users table
CREATE TABLE `pc_users` (
  `user_id` int(11) NOT NULL AUTO_INCREMENT,
  `nickname` varchar(50) NOT NULL,
  `email` varchar(100) NOT NULL,
  `password_hash` varchar(255) NOT NULL,
  `points_balance` decimal(10,2) NOT NULL DEFAULT '0.00',
  `total_earned` decimal(10,2) NOT NULL DEFAULT '0.00',
  `total_spent` decimal(10,2) NOT NULL DEFAULT '0.00',
  `is_admin` tinyint(1) NOT NULL DEFAULT '0',
  `reset_token` varchar(100) DEFAULT NULL,
  `reset_expires` datetime DEFAULT NULL,
  `created_at` datetime NOT NULL,
  `last_login` datetime DEFAULT NULL,
  `status` enum('active','suspended','inactive') NOT NULL DEFAULT 'active',
  PRIMARY KEY (`user_id`),
  UNIQUE KEY `nickname` (`nickname`),
  UNIQUE KEY `email` (`email`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- User sessions table
CREATE TABLE `pc_user_sessions` (
  `session_id` varchar(128) NOT NULL,
  `user_id` int(11) NOT NULL,
  `ip_address` varchar(45) NOT NULL,
  `user_agent` text NOT NULL,
  `last_activity` datetime NOT NULL,
  `data` text,
  PRIMARY KEY (`session_id`),
  KEY `user_id` (`user_id`),
  CONSTRAINT `pc_user_sessions_ibfk_1` FOREIGN KEY (`user_id`) REFERENCES `pc_users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Pyramids table
CREATE TABLE `pc_pyramids` (
  `pyramid_id` int(11) NOT NULL AUTO_INCREMENT,
  `status` enum('active','completed') NOT NULL DEFAULT 'active',
  `level_count` int(11) NOT NULL DEFAULT '4',
  `position_count` int(11) NOT NULL DEFAULT '15',
  `point_cost` decimal(10,2) NOT NULL DEFAULT '1.00',
  `created_at` datetime NOT NULL,
  `completed_at` datetime DEFAULT NULL,
  `zero_position_user_id` int(11) DEFAULT NULL,
  `zero_position_reward` int(11) DEFAULT NULL,
  PRIMARY KEY (`pyramid_id`),
  KEY `zero_position_user_id` (`zero_position_user_id`),
  CONSTRAINT `pc_pyramids_ibfk_1` FOREIGN KEY (`zero_position_user_id`) REFERENCES `pc_users` (`user_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Positions table
CREATE TABLE `pc_positions` (
  `position_id` int(11) NOT NULL AUTO_INCREMENT,
  `pyramid_id` int(11) NOT NULL,
  `user_id` int(11) NOT NULL,
  `position_number` int(11) NOT NULL,
  `position_level` int(11) NOT NULL,
  `is_odd` tinyint(1) DEFAULT NULL,
  `purchased_at` datetime NOT NULL,
  PRIMARY KEY (`position_id`),
  UNIQUE KEY `pyramid_position` (`pyramid_id`,`position_number`),
  KEY `user_id` (`user_id`),
  CONSTRAINT `pc_positions_ibfk_1` FOREIGN KEY (`pyramid_id`) REFERENCES `pc_pyramids` (`pyramid_id`) ON DELETE CASCADE,
  CONSTRAINT `pc_positions_ibfk_2` FOREIGN KEY (`user_id`) REFERENCES `pc_users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Transactions table
CREATE TABLE `pc_transactions` (
  `transaction_id` int(11) NOT NULL AUTO_INCREMENT,
  `user_id` int(11) NOT NULL,
  `type` enum('purchase','reward','cashout') NOT NULL,
  `amount` decimal(10,2) NOT NULL,
  `points` int(11) NOT NULL,
  `status` enum('pending','completed','failed') NOT NULL DEFAULT 'pending',
  `reference_id` varchar(100) DEFAULT NULL,
  `pyramid_id` int(11) DEFAULT NULL,
  `position_id` int(11) DEFAULT NULL,
  `created_at` datetime NOT NULL,
  `updated_at` datetime NOT NULL,
  `notes` text,
  PRIMARY KEY (`transaction_id`),
  KEY `user_id` (`user_id`),
  KEY `pyramid_id` (`pyramid_id`),
  KEY `position_id` (`position_id`),
  CONSTRAINT `pc_transactions_ibfk_1` FOREIGN KEY (`user_id`) REFERENCES `pc_users` (`user_id`) ON DELETE CASCADE,
  CONSTRAINT `pc_transactions_ibfk_2` FOREIGN KEY (`pyramid_id`) REFERENCES `pc_pyramids` (`pyramid_id`) ON DELETE SET NULL,
  CONSTRAINT `pc_transactions_ibfk_3` FOREIGN KEY (`position_id`) REFERENCES `pc_positions` (`position_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Settings table
CREATE TABLE `pc_settings` (
  `setting_id` int(11) NOT NULL AUTO_INCREMENT,
  `setting_key` varchar(50) NOT NULL,
  `setting_value` text NOT NULL,
  `setting_description` text,
  `is_public` tinyint(1) NOT NULL DEFAULT '0',
  `updated_at` datetime NOT NULL,
  PRIMARY KEY (`setting_id`),
  UNIQUE KEY `setting_key` (`setting_key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Insert default settings
INSERT INTO `pc_settings` (`setting_key`, `setting_value`, `setting_description`, `is_public`, `updated_at`) VALUES
('site_name', 'Points Club', 'Website name', 1, NOW()),
('point_cost', '1.00', 'Cost per point in USD', 1, NOW()),
('pyramid_levels', '4', 'Number of levels in pyramid', 1, NOW()),
('cashout_minimum', '10', 'Minimum points required for cashout', 1, NOW()),
('cashout_enabled', '1', 'Whether cashout is enabled', 1, NOW()),
('maintenance_mode', '0', 'Whether site is in maintenance mode', 1, NOW());

-- Create admin user (password: admin123)
INSERT INTO `pc_users` (`nickname`, `email`, `password_hash`, `points_balance`, `is_admin`, `created_at`, `status`) VALUES
('admin', 'admin@example.com', '$2y$10$8tGIIIC0xqCJGQPxqfYcWuLkQZ5LN74QnWSXjFr/0pXCi6ahW.JYe', 100.00, 1, NOW(), 'active');
