<?php
/**
 * Points Club Installer
 * This script guides users through the installation process
 */

// Start session
session_start();

// Enable error reporting for troubleshooting
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Define installation steps
$steps = [
    1 => 'Welcome',
    2 => 'Requirements Check',
    3 => 'Database Setup',
    4 => 'Site Configuration',
    5 => 'Admin Account',
    6 => 'Installation',
    7 => 'Complete'
];

// Get current step
$current_step = isset($_GET['step']) ? (int)$_GET['step'] : 1;

// Validate step
if (!isset($steps[$current_step])) {
    $current_step = 1;
}

// Process form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    switch ($current_step) {
        case 2: // Requirements check - just proceed
            header('Location: index.php?step=3');
            exit;
            
        case 3: // Database setup
            if (isset($_POST['db_host'], $_POST['db_name'], $_POST['db_user'], $_POST['db_pass'])) {
                // Store database info in session
                $_SESSION['db_host'] = $_POST['db_host'];
                $_SESSION['db_name'] = $_POST['db_name'];
                $_SESSION['db_user'] = $_POST['db_user'];
                $_SESSION['db_pass'] = $_POST['db_pass'];
                
                // Test database connection
                $conn = @new mysqli($_POST['db_host'], $_POST['db_user'], $_POST['db_pass']);
                
                if ($conn->connect_error) {
                    $_SESSION['error'] = "Database connection failed: " . $conn->connect_error;
                } else {
                    // Try to create or select the database
                    if (!$conn->select_db($_POST['db_name'])) {
                        // Try to create the database
                        if (!$conn->query("CREATE DATABASE IF NOT EXISTS `{$_POST['db_name']}`")) {
                            $_SESSION['error'] = "Could not create database: " . $conn->error;
                        } else {
                            $conn->select_db($_POST['db_name']);
                            header('Location: index.php?step=4');
                            exit;
                        }
                    } else {
                        header('Location: index.php?step=4');
                        exit;
                    }
                    $conn->close();
                }
            }
            break;
            
        case 4: // Site configuration
            if (isset($_POST['site_url'], $_POST['site_name'])) {
                // Store site info in session
                $_SESSION['site_url'] = $_POST['site_url'];
                $_SESSION['site_name'] = $_POST['site_name'];
                
                header('Location: index.php?step=5');
                exit;
            }
            break;
            
        case 5: // Admin account
            if (isset($_POST['admin_nickname'], $_POST['admin_email'], $_POST['admin_password'], $_POST['admin_confirm_password'])) {
                // Validate password match
                if ($_POST['admin_password'] !== $_POST['admin_confirm_password']) {
                    $_SESSION['error'] = "Passwords do not match";
                } else {
                    // Store admin info in session
                    $_SESSION['admin_nickname'] = $_POST['admin_nickname'];
                    $_SESSION['admin_email'] = $_POST['admin_email'];
                    $_SESSION['admin_password'] = $_POST['admin_password'];
                    
                    header('Location: index.php?step=6');
                    exit;
                }
            }
            break;
            
        case 6: // Installation
            // Perform installation
            $result = performInstallation();
            
            if ($result['success']) {
                header('Location: index.php?step=7');
                exit;
            } else {
                $_SESSION['error'] = $result['message'];
            }
            break;
    }
}

// Function to check system requirements
function checkRequirements() {
    $requirements = [
        'PHP Version' => [
            'required' => '7.4.0',
            'current' => PHP_VERSION,
            'status' => version_compare(PHP_VERSION, '7.4.0', '>=')
        ],
        'MySQLi Extension' => [
            'required' => 'Enabled',
            'current' => extension_loaded('mysqli') ? 'Enabled' : 'Disabled',
            'status' => extension_loaded('mysqli')
        ],
        'PDO Extension' => [
            'required' => 'Enabled',
            'current' => extension_loaded('pdo') ? 'Enabled' : 'Disabled',
            'status' => extension_loaded('pdo')
        ],
        'JSON Extension' => [
            'required' => 'Enabled',
            'current' => extension_loaded('json') ? 'Enabled' : 'Disabled',
            'status' => extension_loaded('json')
        ],
        'File Permissions' => [
            'required' => 'Writable',
            'current' => is_writable('.') ? 'Writable' : 'Not Writable',
            'status' => is_writable('.')
        ]
    ];
    
    $all_passed = true;
    foreach ($requirements as $req) {
        if (!$req['status']) {
            $all_passed = false;
            break;
        }
    }
    
    return [
        'requirements' => $requirements,
        'all_passed' => $all_passed
    ];
}

// Function to perform installation
function performInstallation() {
    try {
        // Check if all required session variables are set
        $required_vars = ['db_host', 'db_name', 'db_user', 'db_pass', 'site_url', 'site_name', 'admin_nickname', 'admin_email', 'admin_password'];
        foreach ($required_vars as $var) {
            if (!isset($_SESSION[$var])) {
                return ['success' => false, 'message' => "Missing required information: $var"];
            }
        }
        
        // Connect to database
        $conn = new mysqli($_SESSION['db_host'], $_SESSION['db_user'], $_SESSION['db_pass']);
        
        if ($conn->connect_error) {
            return ['success' => false, 'message' => "Database connection failed: " . $conn->connect_error];
        }
        
        // Create database if it doesn't exist
        $conn->query("CREATE DATABASE IF NOT EXISTS `{$_SESSION['db_name']}`");
        $conn->select_db($_SESSION['db_name']);
        
        // Import database schema
        $schema_sql = <<<SQL
-- Points Club Database Schema

-- Drop tables if they exist to avoid errors
DROP TABLE IF EXISTS pc_transactions;
DROP TABLE IF EXISTS pc_pyramid_positions;
DROP TABLE IF EXISTS pc_pyramids;
DROP TABLE IF EXISTS pc_sessions;
DROP TABLE IF EXISTS pc_users;
DROP TABLE IF EXISTS pc_settings;

-- Users table
CREATE TABLE pc_users (
    user_id INT AUTO_INCREMENT PRIMARY KEY,
    nickname VARCHAR(50) NOT NULL UNIQUE,
    email VARCHAR(100) NOT NULL UNIQUE,
    password_hash VARCHAR(255) NOT NULL,
    points_balance DECIMAL(10, 2) NOT NULL DEFAULT 0.00,
    is_admin TINYINT(1) NOT NULL DEFAULT 0,
    created_at DATETIME NOT NULL,
    updated_at DATETIME DEFAULT NULL,
    last_login DATETIME DEFAULT NULL,
    status ENUM('active', 'inactive', 'banned') NOT NULL DEFAULT 'active',
    reset_token VARCHAR(100) DEFAULT NULL,
    reset_token_expires DATETIME DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Sessions table
CREATE TABLE pc_sessions (
    session_id VARCHAR(255) PRIMARY KEY,
    user_id INT NOT NULL,
    ip_address VARCHAR(45) NOT NULL,
    user_agent TEXT,
    created_at DATETIME NOT NULL,
    expires_at DATETIME NOT NULL,
    FOREIGN KEY (user_id) REFERENCES pc_users(user_id) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Pyramids table
CREATE TABLE pc_pyramids (
    pyramid_id INT AUTO_INCREMENT PRIMARY KEY,
    status ENUM('active', 'completed') NOT NULL DEFAULT 'active',
    position_count INT NOT NULL,
    filled_positions INT NOT NULL DEFAULT 0,
    point_cost DECIMAL(10, 2) NOT NULL DEFAULT 1.00,
    created_at DATETIME NOT NULL,
    completed_at DATETIME DEFAULT NULL,
    zero_position_user_id INT DEFAULT NULL,
    zero_position_reward INT DEFAULT NULL,
    FOREIGN KEY (zero_position_user_id) REFERENCES pc_users(user_id) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Pyramid positions table
CREATE TABLE pc_pyramid_positions (
    position_id INT AUTO_INCREMENT PRIMARY KEY,
    pyramid_id INT NOT NULL,
    user_id INT NOT NULL,
    position_number INT NOT NULL,
    is_odd TINYINT(1) NOT NULL,
    level INT NOT NULL,
    created_at DATETIME NOT NULL,
    FOREIGN KEY (pyramid_id) REFERENCES pc_pyramids(pyramid_id) ON DELETE CASCADE,
    FOREIGN KEY (user_id) REFERENCES pc_users(user_id) ON DELETE CASCADE,
    UNIQUE KEY (pyramid_id, position_number)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Transactions table
CREATE TABLE pc_transactions (
    transaction_id INT AUTO_INCREMENT PRIMARY KEY,
    user_id INT NOT NULL,
    type ENUM('purchase', 'reward', 'cashout') NOT NULL,
    amount DECIMAL(10, 2) NOT NULL,
    points INT NOT NULL,
    status ENUM('pending', 'completed', 'failed', 'refunded') NOT NULL DEFAULT 'pending',
    reference_id VARCHAR(100) DEFAULT NULL,
    pyramid_id INT DEFAULT NULL,
    position_id INT DEFAULT NULL,
    created_at DATETIME NOT NULL,
    updated_at DATETIME NOT NULL,
    FOREIGN KEY (user_id) REFERENCES pc_users(user_id) ON DELETE CASCADE,
    FOREIGN KEY (pyramid_id) REFERENCES pc_pyramids(pyramid_id) ON DELETE SET NULL,
    FOREIGN KEY (position_id) REFERENCES pc_pyramid_positions(position_id) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Settings table
CREATE TABLE pc_settings (
    setting_key VARCHAR(50) PRIMARY KEY,
    setting_value TEXT NOT NULL,
    created_at DATETIME NOT NULL,
    updated_at DATETIME NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Insert default settings
INSERT INTO pc_settings (setting_key, setting_value, created_at, updated_at) VALUES
('site_name', 'Points Club', NOW(), NOW()),
('point_cost', '1.00', NOW(), NOW()),
('pyramid_levels', '4', NOW(), NOW()),
('cashout_enabled', '1', NOW(), NOW()),
('maintenance_mode', '0', NOW(), NOW());

-- Create initial pyramid if none exists
INSERT INTO pc_pyramids (status, position_count, point_cost, created_at)
VALUES ('active', 15, 1.00, NOW());
SQL;
        
        // Execute each query
        $queries = explode(';', $schema_sql);
        foreach ($queries as $query) {
            $query = trim($query);
            if (!empty($query)) {
                if (!$conn->query($query)) {
                    return ['success' => false, 'message' => "Error executing query: " . $conn->error . " in query: " . $query];
                }
            }
        }
        
        // Create admin user
        $nickname = $conn->real_escape_string($_SESSION['admin_nickname']);
        $email = $conn->real_escape_string($_SESSION['admin_email']);
        $password_hash = password_hash($_SESSION['admin_password'], PASSWORD_DEFAULT);
        
        $query = "INSERT INTO `pc_users` (`nickname`, `email`, `password_hash`, `points_balance`, `is_admin`, `created_at`, `status`) 
                  VALUES ('$nickname', '$email', '$password_hash', 100.00, 1, NOW(), 'active')";
        
        if (!$conn->query($query)) {
            return ['success' => false, 'message' => "Error creating admin user: " . $conn->error];
        }
        
        // Create config directory if it doesn't exist
        if (!file_exists('../src/config')) {
            mkdir('../src/config', 0755, true);
        }
        
        // Generate config file
        $config_content = <<<PHP
<?php
/**
 * Points Club - Configuration File
 * This file contains all the configuration settings for the Points Club website
 */

// Database configuration
define('DB_HOST', '{$_SESSION['db_host']}');
define('DB_NAME', '{$_SESSION['db_name']}');
define('DB_USER', '{$_SESSION['db_user']}');
define('DB_PASS', '{$_SESSION['db_pass']}');
define('DB_PREFIX', 'pc_');

// Site configuration
define('SITE_URL', '{$_SESSION['site_url']}');
define('SITE_NAME', '{$_SESSION['site_name']}');

// Security
define('SECURE_SALT', ''.bin2hex(random_bytes(16)).'');
define('SESSION_LIFETIME', 86400); // 24 hours in seconds

// Email configuration
define('MAIL_FROM', 'noreply@mypointsclub.com');
define('MAIL_NAME', '{$_SESSION['site_name']}');

// Points configuration
define('POINT_COST', 1.00);
define('CASHOUT_ENABLED', true);

// Pyramid configuration
define('PYRAMID_LEVELS', 4);
PHP;
        
        // Write config file
        if (!file_put_contents('../src/config/config.php', $config_content)) {
            return ['success' => false, 'message' => "Error writing config file"];
        }
        
        // Generate database file
        $database_content = <<<PHP
<?php
/**
 * Points Club - Database Class
 * This class handles all database connections and operations
 */

class Database {
    private \$host;
    private \$name;
    private \$user;
    private \$pass;
    private \$prefix;
    private \$conn;
    
    /**
     * Constructor
     * 
     * @param string \$host Database host
     * @param string \$name Database name
     * @param string \$user Database username
     * @param string \$pass Database password
     * @param string \$prefix Table prefix
     */
    public function __construct(\$host, \$name, \$user, \$pass, \$prefix = '') {
        \$this->host = \$host;
        \$this->name = \$name;
        \$this->user = \$user;
        \$this->pass = \$pass;
        \$this->prefix = \$prefix;
    }
    
    /**
     * Connect to the database
     * 
     * @return mysqli Database connection
     */
    public function connect() {
        if (!\$this->conn) {
            \$this->conn = new mysqli(\$this->host, \$this->user, \$this->pass, \$this->name);
            
            if (\$this->conn->connect_error) {
                die("Connection failed: " . \$this->conn->connect_error);
            }
            
            \$this->conn->set_charset("utf8mb4");
        }
        
        return \$this->conn;
    }
    
    /**
     * Close the database connection
     */
    public function close() {
        if (\$this->conn) {
            \$this->conn->close();
            \$this->conn = null;
        }
    }
    
    /**
     * Get table name with prefix
     * 
     * @param string \$table Table name without prefix
     * @return string Table name with prefix
     */
    public function table(\$table) {
        return \$this->prefix . \$table;
    }
    
    /**
     * Execute a query
     * 
     * @param string \$query SQL query
     * @param array \$params Query parameters
     * @return mixed Query result
     */
    public function query(\$query, \$params = []) {
        \$conn = \$this->connect();
        \$stmt = \$conn->prepare(\$query);
        
        if (!\$stmt) {
            return false;
        }
        
        if (!empty(\$params)) {
            \$types = '';
            \$values = [];
            
            foreach (\$params as \$param) {
                if (is_int(\$param)) {
                    \$types .= 'i';
                } elseif (is_float(\$param)) {
                    \$types .= 'd';
                } elseif (is_string(\$param)) {
                    \$types .= 's';
                } else {
                    \$types .= 'b';
                }
                
                \$values[] = \$param;
            }
            
            \$stmt->bind_param(\$types, ...\$values);
        }
        
        \$stmt->execute();
        \$result = \$stmt->get_result();
        \$stmt->close();
        
        return \$result;
    }
}
PHP;
        
        // Write database file
        if (!file_put_contents('../src/config/database.php', $database_content)) {
            return ['success' => false, 'message' => "Error writing database file"];
        }
        
        // Create .htaccess file for clean URLs
        $htaccess = "RewriteEngine On\n";
        $htaccess .= "RewriteCond %{REQUEST_FILENAME} !-f\n";
        $htaccess .= "RewriteCond %{REQUEST_FILENAME} !-d\n";
        $htaccess .= "RewriteRule ^(.*)$ index.php?url=$1 [QSA,L]\n";
        
        if (!file_put_contents('../.htaccess', $htaccess)) {
            return ['success' => false, 'message' => "Error writing .htaccess file"];
        }
        
        // Installation successful
        return ['success' => true];
    } catch (Exception $e) {
        return ['success' => false, 'message' => "Installation error: " . $e->getMessage()];
    }
}

// Get error message if any
$error = isset($_SESSION['error']) ? $_SESSION['error'] : null;
unset($_SESSION['error']);

// Check requirements if on step 2
$requirements_check = null;
if ($current_step === 2) {
    $requirements_check = checkRequirements();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Points Club Installer</title>
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }
        
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            line-height: 1.6;
            color: #333;
            background-color: #f5f5f5;
            padding: 20px;
        }
        
        .container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            border-radius: 5px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            overflow: hidden;
        }
        
        .header {
            background-color: #2196f3;
            color: #fff;
            padding: 20px;
            text-align: center;
        }
        
        .header h1 {
            margin-bottom: 10px;
        }
        
        .steps {
            display: flex;
            background-color: #f0f0f0;
            border-bottom: 1px solid #ddd;
        }
        
        .step {
            flex: 1;
            padding: 10px;
            text-align: center;
            font-size: 14px;
            position: relative;
        }
        
        .step.active {
            background-color: #e3f2fd;
            font-weight: bold;
        }
        
        .step.completed {
            background-color: #e8f5e9;
        }
        
        .step:not(:last-child)::after {
            content: '';
            position: absolute;
            top: 50%;
            right: 0;
            transform: translateY(-50%);
            width: 0;
            height: 0;
            border-top: 5px solid transparent;
            border-bottom: 5px solid transparent;
            border-left: 5px solid #ccc;
        }
        
        .content {
            padding: 30px;
        }
        
        h2 {
            margin-bottom: 20px;
            color: #2196f3;
        }
        
        p {
            margin-bottom: 20px;
        }
        
        .form-group {
            margin-bottom: 20px;
        }
        
        label {
            display: block;
            margin-bottom: 5px;
            font-weight: 500;
        }
        
        input[type="text"],
        input[type="email"],
        input[type="password"] {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 16px;
        }
        
        input:focus {
            outline: none;
            border-color: #2196f3;
            box-shadow: 0 0 0 2px rgba(33, 150, 243, 0.2);
        }
        
        .btn {
            display: inline-block;
            padding: 10px 20px;
            background-color: #2196f3;
            color: #fff;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 16px;
            font-weight: 500;
            text-decoration: none;
        }
        
        .btn:hover {
            background-color: #0d8aee;
        }
        
        .btn-secondary {
            background-color: #e0e0e0;
            color: #333;
        }
        
        .btn-secondary:hover {
            background-color: #d0d0d0;
        }
        
        .actions {
            margin-top: 30px;
            display: flex;
            justify-content: space-between;
        }
        
        .error {
            background-color: #ffebee;
            color: #c62828;
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
            border-left: 4px solid #f44336;
        }
        
        .success {
            background-color: #e8f5e9;
            color: #2e7d32;
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
            border-left: 4px solid #4caf50;
        }
        
        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }
        
        th, td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }
        
        th {
            background-color: #f5f5f5;
            font-weight: 600;
        }
        
        .status-pass {
            color: #2e7d32;
        }
        
        .status-fail {
            color: #c62828;
        }
        
        .loading {
            text-align: center;
            padding: 20px;
        }
        
        .spinner {
            border: 4px solid #f3f3f3;
            border-top: 4px solid #2196f3;
            border-radius: 50%;
            width: 40px;
            height: 40px;
            animation: spin 2s linear infinite;
            margin: 0 auto 20px;
        }
        
        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>Points Club Installer</h1>
            <p>Follow the steps to install your Points Club website</p>
        </div>
        
        <div class="steps">
            <?php foreach ($steps as $step_num => $step_name): ?>
                <div class="step <?php echo $step_num === $current_step ? 'active' : ($step_num < $current_step ? 'completed' : ''); ?>">
                    <?php echo $step_name; ?>
                </div>
            <?php endforeach; ?>
        </div>
        
        <div class="content">
            <?php if ($error): ?>
                <div class="error"><?php echo $error; ?></div>
            <?php endif; ?>
            
            <?php switch ($current_step): ?>
                <?php case 1: // Welcome ?>
                    <h2>Welcome to Points Club Installer</h2>
                    <p>This wizard will guide you through the installation process of your Points Club website.</p>
                    <p>Before you begin, please make sure you have the following information ready:</p>
                    <ul>
                        <li>Database host, name, username, and password</li>
                        <li>Your website URL</li>
                        <li>Admin account details</li>
                    </ul>
                    <p>Click "Next" to begin the installation process.</p>
                    
                    <div class="actions">
                        <div></div>
                        <a href="index.php?step=2" class="btn">Next</a>
                    </div>
                    <?php break; ?>
                
                <?php case 2: // Requirements Check ?>
                    <h2>System Requirements Check</h2>
                    <p>The installer will now check if your server meets the requirements for running Points Club.</p>
                    
                    <table>
                        <thead>
                            <tr>
                                <th>Requirement</th>
                                <th>Required</th>
                                <th>Current</th>
                                <th>Status</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($requirements_check['requirements'] as $name => $req): ?>
                                <tr>
                                    <td><?php echo $name; ?></td>
                                    <td><?php echo $req['required']; ?></td>
                                    <td><?php echo $req['current']; ?></td>
                                    <td class="<?php echo $req['status'] ? 'status-pass' : 'status-fail'; ?>">
                                        <?php echo $req['status'] ? 'Pass' : 'Fail'; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                    
                    <?php if ($requirements_check['all_passed']): ?>
                        <div class="success">Your system meets all requirements!</div>
                    <?php else: ?>
                        <div class="error">Your system does not meet all requirements. Please fix the issues above before continuing.</div>
                    <?php endif; ?>
                    
                    <div class="actions">
                        <a href="index.php?step=1" class="btn btn-secondary">Back</a>
                        <form method="post">
                            <button type="submit" class="btn" <?php echo !$requirements_check['all_passed'] ? 'disabled' : ''; ?>>Next</button>
                        </form>
                    </div>
                    <?php break; ?>
                
                <?php case 3: // Database Setup ?>
                    <h2>Database Setup</h2>
                    <p>Please enter your database connection details. If the database does not exist, the installer will attempt to create it.</p>
                    
                    <form method="post">
                        <div class="form-group">
                            <label for="db_host">Database Host</label>
                            <input type="text" id="db_host" name="db_host" value="<?php echo isset($_SESSION['db_host']) ? $_SESSION['db_host'] : 'localhost'; ?>" required>
                        </div>
                        
                        <div class="form-group">
                            <label for="db_name">Database Name</label>
                            <input type="text" id="db_name" name="db_name" value="<?php echo isset($_SESSION['db_name']) ? $_SESSION['db_name'] : 'pointy_db'; ?>" required>
                        </div>
                        
                        <div class="form-group">
                            <label for="db_user">Database Username</label>
                            <input type="text" id="db_user" name="db_user" value="<?php echo isset($_SESSION['db_user']) ? $_SESSION['db_user'] : ''; ?>" required>
                        </div>
                        
                        <div class="form-group">
                            <label for="db_pass">Database Password</label>
                            <input type="password" id="db_pass" name="db_pass" value="<?php echo isset($_SESSION['db_pass']) ? $_SESSION['db_pass'] : ''; ?>">
                        </div>
                        
                        <div class="actions">
                            <a href="index.php?step=2" class="btn btn-secondary">Back</a>
                            <button type="submit" class="btn">Next</button>
                        </div>
                    </form>
                    <?php break; ?>
                
                <?php case 4: // Site Configuration ?>
                    <h2>Site Configuration</h2>
                    <p>Please enter your website details.</p>
                    
                    <form method="post">
                        <div class="form-group">
                            <label for="site_url">Site URL</label>
                            <input type="text" id="site_url" name="site_url" value="<?php echo isset($_SESSION['site_url']) ? $_SESSION['site_url'] : 'http://' . $_SERVER['HTTP_HOST']; ?>" required>
                            <p class="form-hint">Include http:// or https:// and no trailing slash</p>
                        </div>
                        
                        <div class="form-group">
                            <label for="site_name">Site Name</label>
                            <input type="text" id="site_name" name="site_name" value="<?php echo isset($_SESSION['site_name']) ? $_SESSION['site_name'] : 'Points Club'; ?>" required>
                        </div>
                        
                        <div class="actions">
                            <a href="index.php?step=3" class="btn btn-secondary">Back</a>
                            <button type="submit" class="btn">Next</button>
                        </div>
                    </form>
                    <?php break; ?>
                
                <?php case 5: // Admin Account ?>
                    <h2>Admin Account</h2>
                    <p>Please create an administrator account for your Points Club website.</p>
                    
                    <form method="post">
                        <div class="form-group">
                            <label for="admin_nickname">Admin Nickname</label>
                            <input type="text" id="admin_nickname" name="admin_nickname" value="<?php echo isset($_SESSION['admin_nickname']) ? $_SESSION['admin_nickname'] : 'admin'; ?>" required>
                        </div>
                        
                        <div class="form-group">
                            <label for="admin_email">Admin Email</label>
                            <input type="email" id="admin_email" name="admin_email" value="<?php echo isset($_SESSION['admin_email']) ? $_SESSION['admin_email'] : ''; ?>" required>
                        </div>
                        
                        <div class="form-group">
                            <label for="admin_password">Admin Password</label>
                            <input type="password" id="admin_password" name="admin_password" required>
                            <p class="form-hint">At least 8 characters</p>
                        </div>
                        
                        <div class="form-group">
                            <label for="admin_confirm_password">Confirm Password</label>
                            <input type="password" id="admin_confirm_password" name="admin_confirm_password" required>
                        </div>
                        
                        <div class="actions">
                            <a href="index.php?step=4" class="btn btn-secondary">Back</a>
                            <button type="submit" class="btn">Next</button>
                        </div>
                    </form>
                    <?php break; ?>
                
                <?php case 6: // Installation ?>
                    <h2>Installing Points Club</h2>
                    <p>The installer is now setting up your Points Club website. This may take a moment.</p>
                    
                    <div class="loading">
                        <div class="spinner"></div>
                        <p>Installing...</p>
                    </div>
                    
                    <form method="post" id="install-form">
                        <div class="actions">
                            <a href="index.php?step=5" class="btn btn-secondary">Back</a>
                            <button type="submit" class="btn">Install</button>
                        </div>
                    </form>
                    
                    <script>
                        // Auto-submit the form
                        document.getElementById('install-form').submit();
                    </script>
                    <?php break; ?>
                
                <?php case 7: // Complete ?>
                    <h2>Installation Complete!</h2>
                    <div class="success">Congratulations! Points Club has been successfully installed.</div>
                    
                    <p>You can now access your website and admin area using the links below:</p>
                    
                    <ul>
                        <li><a href="<?php echo $_SESSION['site_url']; ?>/src/index.php">Visit your website</a></li>
                        <li><a href="<?php echo $_SESSION['site_url']; ?>/src/login.php">Admin login</a></li>
                    </ul>
                    
                    <div class="form-group">
                        <label>Admin Login Details</label>
                        <p><strong>Nickname:</strong> <?php echo $_SESSION['admin_nickname']; ?></p>
                        <p><strong>Email:</strong> <?php echo $_SESSION['admin_email']; ?></p>
                    </div>
                    
                    <div class="actions">
                        <div></div>
                        <a href="<?php echo $_SESSION['site_url']; ?>/src/index.php" class="btn">Go to Website</a>
                    </div>
                    
                    <?php
                    // Clear installation session data
                    session_destroy();
                    ?>
                    <?php break; ?>
            <?php endswitch; ?>
        </div>
    </div>
</body>
</html>
