<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'models/pyramid.php';
require_once 'models/transaction.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);
$pyramid = new Pyramid($database);
$transaction = new Transaction($database);

// Check if user is logged in
if (!$session->isLoggedIn()) {
    Utils::setFlashMessage('error', 'You must be logged in to access this page.');
    Utils::redirect('login.php');
}

// Get user data
$user_id = $session->getUserId();
$user_data = $user->getUserById($user_id);

if (!$user_data['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve user data.');
    Utils::redirect('dashboard.php');
}

$user_info = $user_data['user'];

// Get active pyramid
$active_pyramid = $pyramid->getActivePyramid();
if (!$active_pyramid['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve active pyramid.');
    Utils::redirect('dashboard.php');
}

$current_pyramid = $active_pyramid['pyramid'];

// Process point purchase form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['buy_points'])) {
    // Verify CSRF token
    if (!Utils::verifyCsrfToken($_POST['csrf_token'])) {
        Utils::setFlashMessage('error', 'Invalid form submission, please try again.');
        Utils::redirect('buy_points.php');
    }
    
    // Get input
    $points = intval($_POST['points']);
    
    // Validate input
    if ($points <= 0) {
        Utils::setFlashMessage('error', 'Please enter a valid number of points.');
    } else {
        // Create purchase transaction
        $purchase_result = $transaction->createPurchase($user_id, $points, $current_pyramid['point_cost']);
        
        if ($purchase_result['success']) {
            // Redirect to payment page
            Utils::redirect('payment.php?transaction_id=' . $purchase_result['transaction_id']);
        } else {
            Utils::setFlashMessage('error', $purchase_result['message']);
        }
    }
}

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Buy Points - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="dashboard.php">Dashboard</a></li>
                    <li><a href="pyramids.php">Pyramids</a></li>
                    <li class="active"><a href="buy_points.php">Buy Points</a></li>
                    <li><a href="profile.php">My Profile</a></li>
                    <li><a href="logout.php">Logout</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section class="buy-points-section">
                <h2>Buy Points</h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <div class="points-info">
                    <div class="current-balance">
                        <h3>Your Current Balance</h3>
                        <p class="balance"><?php echo $user_info['points_balance']; ?> points</p>
                    </div>
                    
                    <div class="point-cost">
                        <h3>Current Point Cost</h3>
                        <p class="cost">$<?php echo number_format($current_pyramid['point_cost'], 2); ?> per point</p>
                    </div>
                </div>
                
                <div class="buy-points-form">
                    <h3>Purchase Points</h3>
                    <p>Points can be used to play in pyramids or cashed out when earned as rewards.</p>
                    
                    <form action="buy_points.php" method="post">
                        <input type="hidden" name="csrf_token" value="<?php echo Utils::generateCsrfToken(); ?>">
                        
                        <div class="form-group">
                            <label for="points">Number of Points</label>
                            <input type="number" id="points" name="points" min="1" value="1" required>
                        </div>
                        
                        <div class="form-group">
                            <label for="total">Total Cost</label>
                            <div class="total-display">$<span id="total-amount">1.00</span></div>
                        </div>
                        
                        <div class="form-group">
                            <button type="submit" name="buy_points" class="btn btn-primary">Proceed to Payment</button>
                        </div>
                    </form>
                </div>
                
                <div class="points-info-box">
                    <h3>How Points Work</h3>
                    <p>When you buy a point, you are purchasing a position in a pyramid.</p>
                    <p>The top position in a pyramid is the "Zero" Position, which is neither "Odd or Even".</p>
                    <p>The two positions under the Zero position are the first Odd and Even Positions.</p>
                    <p>The next row contains four positions, the next row eight.</p>
                    <p>Once the pyramid is full, the Zero position owner gets the bottom row of credits.</p>
                    <p>You can then use your newly acquired points to play more or cash out.</p>
                </div>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
    
    <script>
        // Calculate total cost based on points
        document.getElementById('points').addEventListener('input', function() {
            const points = parseInt(this.value) || 0;
            const pointCost = <?php echo $current_pyramid['point_cost']; ?>;
            const total = (points * pointCost).toFixed(2);
            document.getElementById('total-amount').textContent = total;
        });
    </script>
</body>
</html>
