<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'models/pyramid.php';
require_once 'models/transaction.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);
$pyramid = new Pyramid($database);
$transaction = new Transaction($database);

// Check if user is logged in
if (!$session->isLoggedIn()) {
    Utils::setFlashMessage('error', 'You must be logged in to access this page.');
    Utils::redirect('login.php');
}

// Get user data
$user_id = $session->getUserId();
$user_data = $user->getUserById($user_id);

if (!$user_data['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve user data.');
    Utils::redirect('login.php');
}

$user_info = $user_data['user'];

// Get active pyramid
$active_pyramid = $pyramid->getActivePyramid();
if (!$active_pyramid['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve active pyramid.');
    Utils::redirect('dashboard.php');
}

$current_pyramid = $active_pyramid['pyramid'];

// Get user's pyramids
$user_pyramids = $pyramid->getUserPyramids($user_id, 5);
$user_pyramid_count = $user_pyramids['success'] ? count($user_pyramids['pyramids']) : 0;

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li class="active"><a href="dashboard.php">Dashboard</a></li>
                    <li><a href="pyramids.php">Pyramids</a></li>
                    <li><a href="buy_points.php">Buy Points</a></li>
                    <li><a href="profile.php">My Profile</a></li>
                    <li><a href="logout.php">Logout</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section class="dashboard-welcome">
                <h2>Welcome, <?php echo htmlspecialchars($session->getNickname()); ?>!</h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
            </section>
            
            <section class="dashboard-stats">
                <div class="stat-container">
                    <div class="stat-box">
                        <h3>Points Balance</h3>
                        <p class="stat-value"><?php echo $user_info['points_balance']; ?></p>
                        <a href="buy_points.php" class="btn btn-sm">Buy More</a>
                    </div>
                    
                    <div class="stat-box">
                        <h3>Active Pyramids</h3>
                        <p class="stat-value"><?php echo $user_pyramid_count; ?></p>
                        <a href="pyramids.php" class="btn btn-sm">View All</a>
                    </div>
                    
                    <div class="stat-box">
                        <h3>Total Earned</h3>
                        <p class="stat-value"><?php echo $user_info['total_earned']; ?></p>
                    </div>
                </div>
            </section>
            
            <section class="dashboard-actions">
                <div class="action-container">
                    <div class="action-box">
                        <h3>Play Now</h3>
                        <p>Join the current active pyramid and start earning rewards!</p>
                        <?php if ($user_info['points_balance'] > 0): ?>
                        <a href="play.php" class="btn btn-primary">Play Now</a>
                        <?php else: ?>
                        <p class="notice">You need points to play. <a href="buy_points.php">Buy some now!</a></p>
                        <?php endif; ?>
                    </div>
                    
                    <div class="action-box">
                        <h3>Current Pyramid</h3>
                        <p>Positions filled: <?php echo $current_pyramid['filled_positions']; ?> / <?php echo $current_pyramid['position_count']; ?></p>
                        <div class="progress-bar">
                            <div class="progress" style="width: <?php echo ($current_pyramid['filled_positions'] / $current_pyramid['position_count']) * 100; ?>%"></div>
                        </div>
                        <a href="pyramid_view.php?id=<?php echo $current_pyramid['pyramid_id']; ?>" class="btn btn-sm">View Pyramid</a>
                    </div>
                </div>
            </section>
            
            <?php if ($user_pyramid_count > 0): ?>
            <section class="dashboard-pyramids">
                <h3>Your Recent Pyramids</h3>
                <div class="pyramid-list">
                    <table>
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>Status</th>
                                <th>Positions</th>
                                <th>Created</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($user_pyramids['pyramids'] as $p): ?>
                            <tr>
                                <td>#<?php echo $p['pyramid_id']; ?></td>
                                <td>
                                    <span class="status-badge status-<?php echo strtolower($p['status']); ?>">
                                        <?php echo ucfirst($p['status']); ?>
                                    </span>
                                </td>
                                <td><?php echo $p['filled_positions']; ?> / <?php echo $p['position_count']; ?></td>
                                <td><?php echo Utils::formatDate($p['created_at'], 'M j, Y'); ?></td>
                                <td>
                                    <a href="pyramid_view.php?id=<?php echo $p['pyramid_id']; ?>" class="btn btn-sm">View</a>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                    
                    <?php if ($user_pyramid_count > 5): ?>
                    <p class="view-all">
                        <a href="pyramids.php">View all your pyramids</a>
                    </p>
                    <?php endif; ?>
                </div>
            </section>
            <?php endif; ?>
            
            <section class="dashboard-info">
                <h3>How Points Club Works</h3>
                <div class="info-container">
                    <div class="info-step">
                        <div class="step-number">1</div>
                        <h4>Buy Points</h4>
                        <p>Purchase points to join pyramids. Each point costs $<?php echo number_format($current_pyramid['point_cost'], 2); ?>.</p>
                    </div>
                    
                    <div class="info-step">
                        <div class="step-number">2</div>
                        <h4>Join Pyramids</h4>
                        <p>Each point buys you a position in a pyramid. Positions are assigned automatically.</p>
                    </div>
                    
                    <div class="info-step">
                        <div class="step-number">3</div>
                        <h4>Earn Rewards</h4>
                        <p>When a pyramid fills up, the Zero position owner receives points from the bottom row.</p>
                    </div>
                    
                    <div class="info-step">
                        <div class="step-number">4</div>
                        <h4>Play or Cash Out</h4>
                        <p>Use your earned points to join more pyramids or cash them out.</p>
                    </div>
                </div>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
</body>
</html>
