<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);

// Process forgot password form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['forgot_password'])) {
    // Verify CSRF token
    if (!Utils::verifyCsrfToken($_POST['csrf_token'])) {
        Utils::setFlashMessage('error', 'Invalid form submission, please try again.');
        Utils::redirect('forgot_password.php');
    }
    
    // Sanitize input
    $email = Utils::sanitizeInput($_POST['email']);
    
    // Validate input
    if (empty($email) || !filter_var($email, FILTER_VALIDATE_EMAIL)) {
        Utils::setFlashMessage('error', 'Please enter a valid email address.');
    } else {
        // Generate reset token
        $result = $user->generateResetToken($email);
        
        if ($result['success']) {
            // In a real application, send email with reset link
            $reset_link = SITE_URL . '/reset_password.php?token=' . $result['token'];
            
            $subject = SITE_NAME . ' - Password Reset';
            $message = "
                <html>
                <head>
                    <title>Password Reset</title>
                </head>
                <body>
                    <h2>Password Reset Request</h2>
                    <p>You have requested to reset your password for your " . SITE_NAME . " account.</p>
                    <p>Please click the link below to reset your password:</p>
                    <p><a href=\"$reset_link\">Reset Password</a></p>
                    <p>Or copy and paste this URL into your browser: $reset_link</p>
                    <p>This link will expire in 1 hour.</p>
                    <p>If you did not request this password reset, please ignore this email.</p>
                </body>
                </html>
            ";
            
            // For development, just show the link
            Utils::setFlashMessage('success', 'Password reset instructions have been sent to your email. <br><strong>Development link:</strong> <a href="' . $reset_link . '">' . $reset_link . '</a>');
            
            // In production, uncomment this line to actually send the email
            // Utils::sendEmail($email, $subject, $message);
            // Utils::setFlashMessage('success', 'Password reset instructions have been sent to your email.');
        } else {
            Utils::setFlashMessage('error', $result['message']);
        }
    }
}

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Forgot Password - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="index.php">Home</a></li>
                    <li><a href="login.php">Login</a></li>
                    <li><a href="register.php">Register</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section class="auth-form">
                <h2>Forgot Password</h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <form action="forgot_password.php" method="post">
                    <input type="hidden" name="csrf_token" value="<?php echo Utils::generateCsrfToken(); ?>">
                    
                    <div class="form-group">
                        <label for="email">Email</label>
                        <input type="email" id="email" name="email" required>
                        <p class="form-hint">Enter the email address associated with your account</p>
                    </div>
                    
                    <div class="form-group">
                        <button type="submit" name="forgot_password" class="btn btn-primary">Reset Password</button>
                    </div>
                    
                    <p class="form-footer">
                        <a href="login.php">Back to Login</a>
                    </p>
                </form>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
    
    <script src="assets/js/script.js"></script>
</body>
</html>
