<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);

// Check if user is already logged in
if ($session->isLoggedIn()) {
    Utils::redirect('dashboard.php');
}

// Process login form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['login'])) {
    // Verify CSRF token
    if (!Utils::verifyCsrfToken($_POST['csrf_token'])) {
        Utils::setFlashMessage('error', 'Invalid form submission, please try again.');
        Utils::redirect('login.php');
    }
    
    // Sanitize input
    $login = Utils::sanitizeInput($_POST['login']);
    $password = $_POST['password'];
    
    // Validate input
    $errors = [];
    
    if (empty($login)) {
        $errors[] = 'Email or nickname is required';
    }
    
    if (empty($password)) {
        $errors[] = 'Password is required';
    }
    
    // If no errors, attempt login
    if (empty($errors)) {
        $result = $user->login($login, $password);
        
        if ($result['success']) {
            // Create session
            $session->create($result['user_id'], [
                'nickname' => $result['nickname'],
                'is_admin' => $result['is_admin']
            ]);
            
            Utils::setFlashMessage('success', 'Login successful!');
            Utils::redirect('dashboard.php');
        } else {
            Utils::setFlashMessage('error', $result['message']);
        }
    } else {
        // Set error messages
        foreach ($errors as $error) {
            Utils::setFlashMessage('error', $error);
        }
    }
}

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="index.php">Home</a></li>
                    <li class="active"><a href="login.php">Login</a></li>
                    <li><a href="register.php">Register</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section class="auth-form">
                <h2>Login to Your Account</h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <form action="login.php" method="post">
                    <input type="hidden" name="csrf_token" value="<?php echo Utils::generateCsrfToken(); ?>">
                    
                    <div class="form-group">
                        <label for="login">Email or Nickname</label>
                        <input type="text" id="login" name="login" value="<?php echo isset($_POST['login']) ? htmlspecialchars($_POST['login']) : ''; ?>" required>
                    </div>
                    
                    <div class="form-group">
                        <label for="password">Password</label>
                        <input type="password" id="password" name="password" required>
                    </div>
                    
                    <div class="form-group">
                        <button type="submit" name="login" class="btn btn-primary">Login</button>
                    </div>
                    
                    <p class="form-footer">
                        <a href="forgot_password.php">Forgot your password?</a><br>
                        Don't have an account? <a href="register.php">Register</a>
                    </p>
                </form>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
    
    <script src="assets/js/script.js"></script>
</body>
</html>
