<?php
// Pyramid class for managing pyramid game logic
class Pyramid {
    private $conn;
    private $table;
    private $positions_table;
    private $users_table;
    private $transactions_table;

    public function __construct($db) {
        $this->conn = $db->connect();
        $this->table = $db->table('pyramids');
        $this->positions_table = $db->table('positions');
        $this->users_table = $db->table('users');
        $this->transactions_table = $db->table('transactions');
    }

    // Create a new pyramid
    public function createPyramid($level_count = 4, $point_cost = 1.00) {
        // Calculate total positions based on level count
        $position_count = pow(2, $level_count) - 1;
        
        // Create new pyramid
        $query = "INSERT INTO " . $this->table . " 
                  (status, level_count, position_count, point_cost, created_at) 
                  VALUES ('active', :level_count, :position_count, :point_cost, NOW())";
        
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':level_count', $level_count, PDO::PARAM_INT);
            $stmt->bindParam(':position_count', $position_count, PDO::PARAM_INT);
            $stmt->bindParam(':point_cost', $point_cost);
            
            if ($stmt->execute()) {
                return [
                    'success' => true,
                    'pyramid_id' => $this->conn->lastInsertId(),
                    'level_count' => $level_count,
                    'position_count' => $position_count,
                    'point_cost' => $point_cost
                ];
            }
            
            return ['success' => false, 'message' => 'Failed to create pyramid'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Get active pyramid with available positions
    public function getActivePyramid() {
        $query = "SELECT p.*, 
                  (SELECT COUNT(*) FROM " . $this->positions_table . " WHERE pyramid_id = p.pyramid_id) as filled_positions 
                  FROM " . $this->table . " p 
                  WHERE p.status = 'active' 
                  HAVING filled_positions < p.position_count 
                  ORDER BY p.created_at ASC 
                  LIMIT 1";
        
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->execute();
            
            if ($stmt->rowCount() > 0) {
                $pyramid = $stmt->fetch();
                return ['success' => true, 'pyramid' => $pyramid];
            }
            
            // No active pyramid with available positions, create a new one
            return $this->createPyramid();
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Get pyramid by ID
    public function getPyramidById($pyramid_id) {
        $query = "SELECT p.*, 
                  (SELECT COUNT(*) FROM " . $this->positions_table . " WHERE pyramid_id = p.pyramid_id) as filled_positions,
                  (SELECT nickname FROM " . $this->users_table . " WHERE user_id = p.zero_position_user_id) as zero_position_user 
                  FROM " . $this->table . " p 
                  WHERE p.pyramid_id = :pyramid_id";
        
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':pyramid_id', $pyramid_id);
            $stmt->execute();
            
            if ($stmt->rowCount() > 0) {
                $pyramid = $stmt->fetch();
                return ['success' => true, 'pyramid' => $pyramid];
            }
            
            return ['success' => false, 'message' => 'Pyramid not found'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Get all pyramids
    public function getAllPyramids($limit = 10, $offset = 0) {
        $query = "SELECT p.*, 
                  (SELECT COUNT(*) FROM " . $this->positions_table . " WHERE pyramid_id = p.pyramid_id) as filled_positions,
                  (SELECT nickname FROM " . $this->users_table . " WHERE user_id = p.zero_position_user_id) as zero_position_user 
                  FROM " . $this->table . " p 
                  ORDER BY p.created_at DESC 
                  LIMIT :limit OFFSET :offset";
        
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':limit', $limit, PDO::PARAM_INT);
            $stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
            $stmt->execute();
            
            $pyramids = $stmt->fetchAll();
            return ['success' => true, 'pyramids' => $pyramids, 'count' => count($pyramids)];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Get user's pyramids
    public function getUserPyramids($user_id, $limit = 10, $offset = 0) {
        $query = "SELECT DISTINCT p.*, 
                  (SELECT COUNT(*) FROM " . $this->positions_table . " WHERE pyramid_id = p.pyramid_id) as filled_positions,
                  (SELECT nickname FROM " . $this->users_table . " WHERE user_id = p.zero_position_user_id) as zero_position_user 
                  FROM " . $this->table . " p 
                  JOIN " . $this->positions_table . " pos ON p.pyramid_id = pos.pyramid_id 
                  WHERE pos.user_id = :user_id 
                  ORDER BY p.created_at DESC 
                  LIMIT :limit OFFSET :offset";
        
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':user_id', $user_id);
            $stmt->bindParam(':limit', $limit, PDO::PARAM_INT);
            $stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
            $stmt->execute();
            
            $pyramids = $stmt->fetchAll();
            return ['success' => true, 'pyramids' => $pyramids, 'count' => count($pyramids)];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Get positions in a pyramid
    public function getPyramidPositions($pyramid_id) {
        $query = "SELECT pos.*, u.nickname 
                  FROM " . $this->positions_table . " pos 
                  JOIN " . $this->users_table . " u ON pos.user_id = u.user_id 
                  WHERE pos.pyramid_id = :pyramid_id 
                  ORDER BY pos.position_level ASC, pos.position_number ASC";
        
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':pyramid_id', $pyramid_id);
            $stmt->execute();
            
            $positions = $stmt->fetchAll();
            return ['success' => true, 'positions' => $positions, 'count' => count($positions)];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Get next available position in pyramid
    public function getNextAvailablePosition($pyramid_id) {
        // Get pyramid info
        $pyramid_result = $this->getPyramidById($pyramid_id);
        if (!$pyramid_result['success']) {
            return $pyramid_result;
        }
        
        $pyramid = $pyramid_result['pyramid'];
        
        // Check if pyramid is active
        if ($pyramid['status'] !== 'active') {
            return ['success' => false, 'message' => 'Pyramid is not active'];
        }
        
        // Get positions already filled
        $positions_result = $this->getPyramidPositions($pyramid_id);
        if (!$positions_result['success']) {
            return $positions_result;
        }
        
        $filled_positions = $positions_result['positions'];
        $filled_position_numbers = array_column($filled_positions, 'position_number');
        
        // Find next available position
        for ($position_number = 0; $position_number < $pyramid['position_count']; $position_number++) {
            if (!in_array($position_number, $filled_position_numbers)) {
                // Calculate level and odd/even status
                if ($position_number === 0) {
                    $level = 0;
                    $is_odd = null; // Zero position is neither odd nor even
                } else {
                    $level = floor(log($position_number + 1, 2));
                    $is_odd = ($position_number % 2 === 1) ? 1 : 0;
                }
                
                return [
                    'success' => true,
                    'position' => [
                        'pyramid_id' => $pyramid_id,
                        'position_number' => $position_number,
                        'position_level' => $level,
                        'is_odd' => $is_odd
                    ]
                ];
            }
        }
        
        return ['success' => false, 'message' => 'No available positions in this pyramid'];
    }

    // Assign position to user
    public function assignPosition($user_id, $pyramid_id, $position_data) {
        // Start transaction
        $this->conn->beginTransaction();
        
        try {
            // Insert position
            $query = "INSERT INTO " . $this->positions_table . " 
                      (pyramid_id, user_id, position_number, position_level, is_odd, purchased_at) 
                      VALUES (:pyramid_id, :user_id, :position_number, :position_level, :is_odd, NOW())";
            
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':pyramid_id', $pyramid_id);
            $stmt->bindParam(':user_id', $user_id);
            $stmt->bindParam(':position_number', $position_data['position_number']);
            $stmt->bindParam(':position_level', $position_data['position_level']);
            $stmt->bindParam(':is_odd', $position_data['is_odd']);
            $stmt->execute();
            
            $position_id = $this->conn->lastInsertId();
            
            // If this is the zero position, update the pyramid
            if ($position_data['position_number'] === 0) {
                $update_query = "UPDATE " . $this->table . " 
                                SET zero_position_user_id = :user_id 
                                WHERE pyramid_id = :pyramid_id";
                
                $update_stmt = $this->conn->prepare($update_query);
                $update_stmt->bindParam(':user_id', $user_id);
                $update_stmt->bindParam(':pyramid_id', $pyramid_id);
                $update_stmt->execute();
            }
            
            // Check if pyramid is now full
            $pyramid_result = $this->getPyramidById($pyramid_id);
            $pyramid = $pyramid_result['pyramid'];
            
            if ($pyramid['filled_positions'] >= $pyramid['position_count']) {
                // Pyramid is full, process rewards
                $this->completePyramid($pyramid_id);
            }
            
            // Commit transaction
            $this->conn->commit();
            
            return [
                'success' => true,
                'message' => 'Position assigned successfully',
                'position_id' => $position_id
            ];
        } catch (PDOException $e) {
            // Rollback transaction on error
            $this->conn->rollBack();
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Complete pyramid and distribute rewards
    private function completePyramid($pyramid_id) {
        // Get pyramid info
        $pyramid_result = $this->getPyramidById($pyramid_id);
        if (!$pyramid_result['success']) {
            return $pyramid_result;
        }
        
        $pyramid = $pyramid_result['pyramid'];
        
        // Get positions
        $positions_result = $this->getPyramidPositions($pyramid_id);
        if (!$positions_result['success']) {
            return $positions_result;
        }
        
        $positions = $positions_result['positions'];
        
        // Calculate reward (number of positions in bottom row)
        $bottom_level = $pyramid['level_count'] - 1;
        $reward_points = pow(2, $bottom_level);
        
        // Update pyramid status
        $update_query = "UPDATE " . $this->table . " 
                        SET status = 'completed', completed_at = NOW(), zero_position_reward = :reward 
                        WHERE pyramid_id = :pyramid_id";
        
        $update_stmt = $this->conn->prepare($update_query);
        $update_stmt->bindParam(':reward', $reward_points);
        $update_stmt->bindParam(':pyramid_id', $pyramid_id);
        $update_stmt->execute();
        
        // Add reward to zero position user
        if ($pyramid['zero_position_user_id']) {
            // Update user points balance
            $points_query = "UPDATE " . $this->users_table . " 
                            SET points_balance = points_balance + :reward, 
                                total_earned = total_earned + :reward 
                            WHERE user_id = :user_id";
            
            $points_stmt = $this->conn->prepare($points_query);
            $points_stmt->bindParam(':reward', $reward_points);
            $points_stmt->bindParam(':user_id', $pyramid['zero_position_user_id']);
            $points_stmt->execute();
            
            // Record transaction
            $transaction_query = "INSERT INTO " . $this->transactions_table . " 
                                 (user_id, type, amount, points, status, pyramid_id, created_at, updated_at) 
                                 VALUES (:user_id, 'reward', :amount, :points, 'completed', :pyramid_id, NOW(), NOW())";
            
            $amount = $reward_points * $pyramid['point_cost'];
            
            $transaction_stmt = $this->conn->prepare($transaction_query);
            $transaction_stmt->bindParam(':user_id', $pyramid['zero_position_user_id']);
            $transaction_stmt->bindParam(':amount', $amount);
            $transaction_stmt->bindParam(':points', $reward_points);
            $transaction_stmt->bindParam(':pyramid_id', $pyramid_id);
            $transaction_stmt->execute();
        }
        
        return [
            'success' => true,
            'message' => 'Pyramid completed successfully',
            'reward_points' => $reward_points
        ];
    }

    // Get pyramid visualization data
    public function getPyramidVisualization($pyramid_id) {
        // Get pyramid info
        $pyramid_result = $this->getPyramidById($pyramid_id);
        if (!$pyramid_result['success']) {
            return $pyramid_result;
        }
        
        $pyramid = $pyramid_result['pyramid'];
        
        // Get positions
        $positions_result = $this->getPyramidPositions($pyramid_id);
        if (!$positions_result['success']) {
            return $positions_result;
        }
        
        $positions = $positions_result['positions'];
        
        // Organize positions by level
        $levels = [];
        for ($i = 0; $i < $pyramid['level_count']; $i++) {
            $levels[$i] = [];
        }
        
        foreach ($positions as $position) {
            $levels[$position['position_level']][$position['position_number']] = $position;
        }
        
        // Calculate empty positions
        for ($level = 0; $level < $pyramid['level_count']; $level++) {
            $positions_in_level = pow(2, $level);
            $start_position = pow(2, $level) - 1;
            
            for ($i = 0; $i < $positions_in_level; $i++) {
                $position_number = $start_position + $i;
                if (!isset($levels[$level][$position_number])) {
                    $levels[$level][$position_number] = [
                        'position_number' => $position_number,
                        'position_level' => $level,
                        'is_odd' => ($position_number % 2 === 1) ? 1 : 0,
                        'empty' => true
                    ];
                }
            }
            
            // Sort positions by number
            ksort($levels[$level]);
        }
        
        return [
            'success' => true,
            'pyramid' => $pyramid,
            'levels' => $levels
        ];
    }
}
