<?php
// Session management class
class Session {
    private $db;
    private $table;
    private $user_id;
    
    public function __construct($db) {
        $this->db = $db;
        $this->table = $db->table('user_sessions');
        
        // Start session if not already started
        if (session_status() == PHP_SESSION_NONE) {
            session_name(SESSION_NAME);
            session_start();
        }
        
        $this->user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
    }
    
    // Create new session
    public function create($user_id, $user_data) {
        // Regenerate session ID for security
        session_regenerate_id(true);
        
        // Set session data
        $_SESSION['user_id'] = $user_id;
        $_SESSION['nickname'] = $user_data['nickname'];
        $_SESSION['is_admin'] = $user_data['is_admin'];
        $_SESSION['logged_in'] = true;
        $_SESSION['last_activity'] = time();
        
        $this->user_id = $user_id;
        
        // Store session in database
        $this->storeSession();
        
        return true;
    }
    
    // Store session in database
    private function storeSession() {
        $conn = $this->db->connect();
        $session_id = session_id();
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];
        $data = json_encode($_SESSION);
        
        // Check if session already exists
        $query = "SELECT session_id FROM " . $this->table . " WHERE session_id = :session_id";
        $stmt = $conn->prepare($query);
        $stmt->bindParam(':session_id', $session_id);
        $stmt->execute();
        
        if ($stmt->rowCount() > 0) {
            // Update existing session
            $query = "UPDATE " . $this->table . " 
                      SET user_id = :user_id, ip_address = :ip_address, 
                      user_agent = :user_agent, last_activity = NOW(), data = :data 
                      WHERE session_id = :session_id";
        } else {
            // Insert new session
            $query = "INSERT INTO " . $this->table . " 
                      (session_id, user_id, ip_address, user_agent, last_activity, data) 
                      VALUES (:session_id, :user_id, :ip_address, :user_agent, NOW(), :data)";
        }
        
        try {
            $stmt = $conn->prepare($query);
            $stmt->bindParam(':session_id', $session_id);
            $stmt->bindParam(':user_id', $this->user_id);
            $stmt->bindParam(':ip_address', $ip_address);
            $stmt->bindParam(':user_agent', $user_agent);
            $stmt->bindParam(':data', $data);
            $stmt->execute();
            return true;
        } catch (PDOException $e) {
            error_log('Session storage error: ' . $e->getMessage());
            return false;
        }
    }
    
    // Check if user is logged in
    public function isLoggedIn() {
        return isset($_SESSION['logged_in']) && $_SESSION['logged_in'] === true;
    }
    
    // Check if user is admin
    public function isAdmin() {
        return $this->isLoggedIn() && isset($_SESSION['is_admin']) && $_SESSION['is_admin'] === 1;
    }
    
    // Get current user ID
    public function getUserId() {
        return $this->user_id;
    }
    
    // Get current user nickname
    public function getNickname() {
        return isset($_SESSION['nickname']) ? $_SESSION['nickname'] : null;
    }
    
    // Destroy session
    public function destroy() {
        $conn = $this->db->connect();
        $session_id = session_id();
        
        // Remove from database
        $query = "DELETE FROM " . $this->table . " WHERE session_id = :session_id";
        try {
            $stmt = $conn->prepare($query);
            $stmt->bindParam(':session_id', $session_id);
            $stmt->execute();
        } catch (PDOException $e) {
            error_log('Session deletion error: ' . $e->getMessage());
        }
        
        // Unset all session variables
        $_SESSION = array();
        
        // Delete the session cookie
        if (ini_get("session.use_cookies")) {
            $params = session_get_cookie_params();
            setcookie(session_name(), '', time() - 42000,
                $params["path"], $params["domain"],
                $params["secure"], $params["httponly"]
            );
        }
        
        // Destroy the session
        session_destroy();
        
        return true;
    }
    
    // Clean up old sessions
    public function cleanSessions($max_lifetime = 86400) { // Default 24 hours
        $conn = $this->db->connect();
        
        $query = "DELETE FROM " . $this->table . " 
                  WHERE last_activity < DATE_SUB(NOW(), INTERVAL :lifetime SECOND)";
        
        try {
            $stmt = $conn->prepare($query);
            $stmt->bindParam(':lifetime', $max_lifetime, PDO::PARAM_INT);
            $stmt->execute();
            return true;
        } catch (PDOException $e) {
            error_log('Session cleanup error: ' . $e->getMessage());
            return false;
        }
    }
    
    // Update session last activity
    public function updateActivity() {
        $_SESSION['last_activity'] = time();
        $this->storeSession();
    }
}
