<?php
// Transaction class for managing point purchases and cashouts
class Transaction {
    private $conn;
    private $table;
    private $users_table;

    public function __construct($db) {
        $this->conn = $db->connect();
        $this->table = $db->table('transactions');
        $this->users_table = $db->table('users');
    }

    // Create a new point purchase transaction
    public function createPurchase($user_id, $points, $point_cost = 1.00) {
        // Calculate amount
        $amount = $points * $point_cost;
        
        // Start transaction
        $this->conn->beginTransaction();
        
        try {
            // Create transaction record
            $query = "INSERT INTO " . $this->table . " 
                      (user_id, type, amount, points, status, created_at, updated_at) 
                      VALUES (:user_id, 'purchase', :amount, :points, 'pending', NOW(), NOW())";
            
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':user_id', $user_id);
            $stmt->bindParam(':amount', $amount);
            $stmt->bindParam(':points', $points);
            
            $stmt->execute();
            $transaction_id = $this->conn->lastInsertId();
            
            // Commit transaction
            $this->conn->commit();
            
            return [
                'success' => true,
                'transaction_id' => $transaction_id,
                'amount' => $amount,
                'points' => $points
            ];
        } catch (PDOException $e) {
            // Rollback transaction on error
            $this->conn->rollBack();
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Complete a purchase transaction (after payment)
    public function completePurchase($transaction_id, $reference_id = null) {
        // Start transaction
        $this->conn->beginTransaction();
        
        try {
            // Get transaction details
            $query = "SELECT * FROM " . $this->table . " 
                      WHERE transaction_id = :transaction_id AND type = 'purchase' AND status = 'pending'";
            
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':transaction_id', $transaction_id);
            $stmt->execute();
            
            if ($stmt->rowCount() === 0) {
                $this->conn->rollBack();
                return ['success' => false, 'message' => 'Transaction not found or already processed'];
            }
            
            $transaction = $stmt->fetch();
            
            // Update transaction status
            $update_query = "UPDATE " . $this->table . " 
                            SET status = 'completed', reference_id = :reference_id, updated_at = NOW() 
                            WHERE transaction_id = :transaction_id";
            
            $update_stmt = $this->conn->prepare($update_query);
            $update_stmt->bindParam(':reference_id', $reference_id);
            $update_stmt->bindParam(':transaction_id', $transaction_id);
            $update_stmt->execute();
            
            // Update user points balance
            $points_query = "UPDATE " . $this->users_table . " 
                            SET points_balance = points_balance + :points, 
                                total_spent = total_spent + :amount 
                            WHERE user_id = :user_id";
            
            $points_stmt = $this->conn->prepare($points_query);
            $points_stmt->bindParam(':points', $transaction['points']);
            $points_stmt->bindParam(':amount', $transaction['amount']);
            $points_stmt->bindParam(':user_id', $transaction['user_id']);
            $points_stmt->execute();
            
            // Commit transaction
            $this->conn->commit();
            
            return [
                'success' => true,
                'message' => 'Purchase completed successfully',
                'transaction' => $transaction
            ];
        } catch (PDOException $e) {
            // Rollback transaction on error
            $this->conn->rollBack();
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Create a cashout transaction
    public function createCashout($user_id, $points) {
        // Get user points balance
        $query = "SELECT points_balance FROM " . $this->users_table . " WHERE user_id = :user_id";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':user_id', $user_id);
        $stmt->execute();
        
        if ($stmt->rowCount() === 0) {
            return ['success' => false, 'message' => 'User not found'];
        }
        
        $user = $stmt->fetch();
        
        // Check if user has enough points
        if ($user['points_balance'] < $points) {
            return ['success' => false, 'message' => 'Insufficient points balance'];
        }
        
        // Calculate amount (1 point = $1)
        $amount = $points;
        
        // Start transaction
        $this->conn->beginTransaction();
        
        try {
            // Create transaction record
            $query = "INSERT INTO " . $this->table . " 
                      (user_id, type, amount, points, status, created_at, updated_at) 
                      VALUES (:user_id, 'cashout', :amount, :points, 'pending', NOW(), NOW())";
            
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':user_id', $user_id);
            $stmt->bindParam(':amount', $amount);
            $stmt->bindParam(':points', $points);
            
            $stmt->execute();
            $transaction_id = $this->conn->lastInsertId();
            
            // Update user points balance
            $points_query = "UPDATE " . $this->users_table . " 
                            SET points_balance = points_balance - :points 
                            WHERE user_id = :user_id";
            
            $points_stmt = $this->conn->prepare($points_query);
            $points_stmt->bindParam(':points', $points);
            $points_stmt->bindParam(':user_id', $user_id);
            $points_stmt->execute();
            
            // Commit transaction
            $this->conn->commit();
            
            return [
                'success' => true,
                'transaction_id' => $transaction_id,
                'amount' => $amount,
                'points' => $points
            ];
        } catch (PDOException $e) {
            // Rollback transaction on error
            $this->conn->rollBack();
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Complete a cashout transaction (after processing)
    public function completeCashout($transaction_id, $reference_id = null) {
        // Start transaction
        $this->conn->beginTransaction();
        
        try {
            // Get transaction details
            $query = "SELECT * FROM " . $this->table . " 
                      WHERE transaction_id = :transaction_id AND type = 'cashout' AND status = 'pending'";
            
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':transaction_id', $transaction_id);
            $stmt->execute();
            
            if ($stmt->rowCount() === 0) {
                $this->conn->rollBack();
                return ['success' => false, 'message' => 'Transaction not found or already processed'];
            }
            
            $transaction = $stmt->fetch();
            
            // Update transaction status
            $update_query = "UPDATE " . $this->table . " 
                            SET status = 'completed', reference_id = :reference_id, updated_at = NOW() 
                            WHERE transaction_id = :transaction_id";
            
            $update_stmt = $this->conn->prepare($update_query);
            $update_stmt->bindParam(':reference_id', $reference_id);
            $update_stmt->bindParam(':transaction_id', $transaction_id);
            $update_stmt->execute();
            
            // Commit transaction
            $this->conn->commit();
            
            return [
                'success' => true,
                'message' => 'Cashout completed successfully',
                'transaction' => $transaction
            ];
        } catch (PDOException $e) {
            // Rollback transaction on error
            $this->conn->rollBack();
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Get user transactions
    public function getUserTransactions($user_id, $limit = 10, $offset = 0) {
        $query = "SELECT t.*, 
                  p.pyramid_id, p.status as pyramid_status 
                  FROM " . $this->table . " t 
                  LEFT JOIN " . $db->table('pyramids') . " p ON t.pyramid_id = p.pyramid_id 
                  WHERE t.user_id = :user_id 
                  ORDER BY t.created_at DESC 
                  LIMIT :limit OFFSET :offset";
        
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':user_id', $user_id);
            $stmt->bindParam(':limit', $limit, PDO::PARAM_INT);
            $stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
            $stmt->execute();
            
            $transactions = $stmt->fetchAll();
            return ['success' => true, 'transactions' => $transactions, 'count' => count($transactions)];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Get transaction by ID
    public function getTransactionById($transaction_id) {
        $query = "SELECT t.*, 
                  p.pyramid_id, p.status as pyramid_status 
                  FROM " . $this->table . " t 
                  LEFT JOIN " . $db->table('pyramids') . " p ON t.pyramid_id = p.pyramid_id 
                  WHERE t.transaction_id = :transaction_id";
        
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':transaction_id', $transaction_id);
            $stmt->execute();
            
            if ($stmt->rowCount() > 0) {
                $transaction = $stmt->fetch();
                return ['success' => true, 'transaction' => $transaction];
            }
            
            return ['success' => false, 'message' => 'Transaction not found'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }
}
