<?php
// User class for authentication and user management
class User {
    private $conn;
    private $table;

    public function __construct($db) {
        $this->conn = $db->connect();
        $this->table = $db->table('users');
    }

    // Register a new user
    public function register($nickname, $email, $password) {
        // Validate input
        if (empty($nickname) || empty($email) || empty($password)) {
            return ['success' => false, 'message' => 'All fields are required'];
        }

        if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            return ['success' => false, 'message' => 'Invalid email format'];
        }

        if (strlen($password) < 8) {
            return ['success' => false, 'message' => 'Password must be at least 8 characters'];
        }

        // Check if nickname or email already exists
        if ($this->nicknameExists($nickname)) {
            return ['success' => false, 'message' => 'Nickname already taken'];
        }

        if ($this->emailExists($email)) {
            return ['success' => false, 'message' => 'Email already registered'];
        }

        // Hash password
        $password_hash = password_hash($password, PASSWORD_DEFAULT);

        // Prepare query
        $query = "INSERT INTO " . $this->table . " 
                  (nickname, email, password_hash, created_at, status) 
                  VALUES (:nickname, :email, :password_hash, NOW(), 'active')";

        try {
            // Prepare statement
            $stmt = $this->conn->prepare($query);

            // Bind parameters
            $stmt->bindParam(':nickname', $nickname);
            $stmt->bindParam(':email', $email);
            $stmt->bindParam(':password_hash', $password_hash);

            // Execute query
            if ($stmt->execute()) {
                return [
                    'success' => true, 
                    'message' => 'Registration successful', 
                    'user_id' => $this->conn->lastInsertId()
                ];
            }

            return ['success' => false, 'message' => 'Registration failed'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Login user
    public function login($login, $password) {
        // Determine if login is email or nickname
        $is_email = filter_var($login, FILTER_VALIDATE_EMAIL);
        $field = $is_email ? 'email' : 'nickname';

        // Prepare query
        $query = "SELECT user_id, nickname, email, password_hash, is_admin, status 
                  FROM " . $this->table . " 
                  WHERE " . $field . " = :login";

        try {
            // Prepare statement
            $stmt = $this->conn->prepare($query);

            // Bind parameter
            $stmt->bindParam(':login', $login);

            // Execute query
            $stmt->execute();

            // Check if user exists
            if ($stmt->rowCount() > 0) {
                $row = $stmt->fetch();

                // Check if account is active
                if ($row['status'] !== 'active') {
                    return ['success' => false, 'message' => 'Account is not active'];
                }

                // Verify password
                if (password_verify($password, $row['password_hash'])) {
                    // Update last login
                    $this->updateLastLogin($row['user_id']);

                    // Return user data
                    return [
                        'success' => true,
                        'message' => 'Login successful',
                        'user_id' => $row['user_id'],
                        'nickname' => $row['nickname'],
                        'email' => $row['email'],
                        'is_admin' => $row['is_admin']
                    ];
                }

                return ['success' => false, 'message' => 'Invalid password'];
            }

            return ['success' => false, 'message' => 'User not found'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Update last login timestamp
    private function updateLastLogin($user_id) {
        $query = "UPDATE " . $this->table . " 
                  SET last_login = NOW() 
                  WHERE user_id = :user_id";

        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':user_id', $user_id);
            $stmt->execute();
        } catch (PDOException $e) {
            // Log error but don't interrupt login process
            error_log('Failed to update last login: ' . $e->getMessage());
        }
    }

    // Check if nickname exists
    public function nicknameExists($nickname) {
        $query = "SELECT user_id FROM " . $this->table . " WHERE nickname = :nickname";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':nickname', $nickname);
        $stmt->execute();
        return $stmt->rowCount() > 0;
    }

    // Check if email exists
    public function emailExists($email) {
        $query = "SELECT user_id FROM " . $this->table . " WHERE email = :email";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':email', $email);
        $stmt->execute();
        return $stmt->rowCount() > 0;
    }

    // Generate password reset token
    public function generateResetToken($email) {
        if (!$this->emailExists($email)) {
            return ['success' => false, 'message' => 'Email not found'];
        }

        // Generate token
        $token = bin2hex(random_bytes(32));
        $expires = date('Y-m-d H:i:s', strtotime('+1 hour'));

        // Update user with token
        $query = "UPDATE " . $this->table . " 
                  SET reset_token = :token, reset_expires = :expires 
                  WHERE email = :email";

        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':token', $token);
            $stmt->bindParam(':expires', $expires);
            $stmt->bindParam(':email', $email);

            if ($stmt->execute()) {
                return [
                    'success' => true,
                    'message' => 'Reset token generated',
                    'token' => $token,
                    'expires' => $expires
                ];
            }

            return ['success' => false, 'message' => 'Failed to generate reset token'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Verify reset token
    public function verifyResetToken($token) {
        $query = "SELECT user_id, email FROM " . $this->table . " 
                  WHERE reset_token = :token AND reset_expires > NOW()";

        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':token', $token);
            $stmt->execute();

            if ($stmt->rowCount() > 0) {
                $row = $stmt->fetch();
                return [
                    'success' => true,
                    'message' => 'Valid token',
                    'user_id' => $row['user_id'],
                    'email' => $row['email']
                ];
            }

            return ['success' => false, 'message' => 'Invalid or expired token'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Reset password
    public function resetPassword($token, $new_password) {
        // Verify token
        $verify = $this->verifyResetToken($token);
        if (!$verify['success']) {
            return $verify;
        }

        // Validate password
        if (strlen($new_password) < 8) {
            return ['success' => false, 'message' => 'Password must be at least 8 characters'];
        }

        // Hash new password
        $password_hash = password_hash($new_password, PASSWORD_DEFAULT);

        // Update password and clear token
        $query = "UPDATE " . $this->table . " 
                  SET password_hash = :password_hash, reset_token = NULL, reset_expires = NULL 
                  WHERE user_id = :user_id";

        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':password_hash', $password_hash);
            $stmt->bindParam(':user_id', $verify['user_id']);

            if ($stmt->execute()) {
                return ['success' => true, 'message' => 'Password reset successful'];
            }

            return ['success' => false, 'message' => 'Failed to reset password'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Get user by ID
    public function getUserById($user_id) {
        $query = "SELECT user_id, nickname, email, points_balance, total_earned, 
                  total_spent, is_admin, created_at, last_login, status 
                  FROM " . $this->table . " 
                  WHERE user_id = :user_id";

        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':user_id', $user_id);
            $stmt->execute();

            if ($stmt->rowCount() > 0) {
                return [
                    'success' => true,
                    'user' => $stmt->fetch()
                ];
            }

            return ['success' => false, 'message' => 'User not found'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Update user profile
    public function updateProfile($user_id, $nickname, $email) {
        // Get current user data
        $current_user = $this->getUserById($user_id);
        if (!$current_user['success']) {
            return $current_user;
        }

        // Check if nickname changed and already exists
        if ($nickname !== $current_user['user']['nickname'] && $this->nicknameExists($nickname)) {
            return ['success' => false, 'message' => 'Nickname already taken'];
        }

        // Check if email changed and already exists
        if ($email !== $current_user['user']['email'] && $this->emailExists($email)) {
            return ['success' => false, 'message' => 'Email already registered'];
        }

        // Update profile
        $query = "UPDATE " . $this->table . " 
                  SET nickname = :nickname, email = :email 
                  WHERE user_id = :user_id";

        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':nickname', $nickname);
            $stmt->bindParam(':email', $email);
            $stmt->bindParam(':user_id', $user_id);

            if ($stmt->execute()) {
                return ['success' => true, 'message' => 'Profile updated successfully'];
            }

            return ['success' => false, 'message' => 'Failed to update profile'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }

    // Change password
    public function changePassword($user_id, $current_password, $new_password) {
        // Get current user data
        $query = "SELECT password_hash FROM " . $this->table . " WHERE user_id = :user_id";
        
        try {
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':user_id', $user_id);
            $stmt->execute();

            if ($stmt->rowCount() > 0) {
                $row = $stmt->fetch();

                // Verify current password
                if (!password_verify($current_password, $row['password_hash'])) {
                    return ['success' => false, 'message' => 'Current password is incorrect'];
                }

                // Validate new password
                if (strlen($new_password) < 8) {
                    return ['success' => false, 'message' => 'New password must be at least 8 characters'];
                }

                // Hash new password
                $password_hash = password_hash($new_password, PASSWORD_DEFAULT);

                // Update password
                $update_query = "UPDATE " . $this->table . " 
                                SET password_hash = :password_hash 
                                WHERE user_id = :user_id";

                $update_stmt = $this->conn->prepare($update_query);
                $update_stmt->bindParam(':password_hash', $password_hash);
                $update_stmt->bindParam(':user_id', $user_id);

                if ($update_stmt->execute()) {
                    return ['success' => true, 'message' => 'Password changed successfully'];
                }

                return ['success' => false, 'message' => 'Failed to change password'];
            }

            return ['success' => false, 'message' => 'User not found'];
        } catch (PDOException $e) {
            return ['success' => false, 'message' => 'Database error: ' . $e->getMessage()];
        }
    }
}
