<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'models/transaction.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);
$transaction = new Transaction($database);

// Check if user is logged in
if (!$session->isLoggedIn()) {
    Utils::setFlashMessage('error', 'You must be logged in to access this page.');
    Utils::redirect('login.php');
}

// Check if transaction ID is provided
if (!isset($_GET['transaction_id']) || empty($_GET['transaction_id'])) {
    Utils::setFlashMessage('error', 'Invalid transaction ID.');
    Utils::redirect('buy_points.php');
}

$transaction_id = intval($_GET['transaction_id']);

// Get transaction data
$transaction_data = $transaction->getTransactionById($transaction_id);
if (!$transaction_data['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve transaction data.');
    Utils::redirect('buy_points.php');
}

$transaction_info = $transaction_data['transaction'];

// Check if transaction belongs to current user
if ($transaction_info['user_id'] != $session->getUserId()) {
    Utils::setFlashMessage('error', 'You do not have permission to view this transaction.');
    Utils::redirect('buy_points.php');
}

// Check if transaction is already completed
if ($transaction_info['status'] !== 'pending') {
    Utils::setFlashMessage('info', 'This transaction has already been processed.');
    Utils::redirect('dashboard.php');
}

// Process payment form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['process_payment'])) {
    // Verify CSRF token
    if (!Utils::verifyCsrfToken($_POST['csrf_token'])) {
        Utils::setFlashMessage('error', 'Invalid form submission, please try again.');
        Utils::redirect('payment.php?transaction_id=' . $transaction_id);
    }
    
    // Mock payment processing
    // In a real application, this would integrate with PayPal or another payment processor
    $payment_method = $_POST['payment_method'];
    $reference_id = 'MOCK_' . strtoupper(Utils::generateRandomString(8));
    
    // Complete the transaction
    $complete_result = $transaction->completePurchase($transaction_id, $reference_id);
    
    if ($complete_result['success']) {
        Utils::setFlashMessage('success', 'Payment processed successfully! ' . $transaction_info['points'] . ' points have been added to your account.');
        Utils::redirect('dashboard.php');
    } else {
        Utils::setFlashMessage('error', $complete_result['message']);
        Utils::redirect('payment.php?transaction_id=' . $transaction_id);
    }
}

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Payment - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="dashboard.php">Dashboard</a></li>
                    <li><a href="pyramids.php">Pyramids</a></li>
                    <li><a href="buy_points.php">Buy Points</a></li>
                    <li><a href="profile.php">My Profile</a></li>
                    <li><a href="logout.php">Logout</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section class="payment-section">
                <h2>Complete Your Purchase</h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <div class="payment-summary">
                    <h3>Order Summary</h3>
                    <div class="summary-details">
                        <div class="summary-row">
                            <div class="summary-label">Points:</div>
                            <div class="summary-value"><?php echo $transaction_info['points']; ?></div>
                        </div>
                        <div class="summary-row">
                            <div class="summary-label">Price per Point:</div>
                            <div class="summary-value">$<?php echo number_format($transaction_info['amount'] / $transaction_info['points'], 2); ?></div>
                        </div>
                        <div class="summary-row total">
                            <div class="summary-label">Total:</div>
                            <div class="summary-value">$<?php echo number_format($transaction_info['amount'], 2); ?></div>
                        </div>
                    </div>
                </div>
                
                <div class="payment-form">
                    <h3>Payment Method</h3>
                    <p class="payment-notice">
                        <strong>Note:</strong> This is a demonstration payment system. No actual charges will be made.
                    </p>
                    
                    <form action="payment.php?transaction_id=<?php echo $transaction_id; ?>" method="post">
                        <input type="hidden" name="csrf_token" value="<?php echo Utils::generateCsrfToken(); ?>">
                        
                        <div class="form-group">
                            <label>Select Payment Method</label>
                            <div class="payment-methods">
                                <div class="payment-method">
                                    <input type="radio" id="paypal" name="payment_method" value="paypal" checked>
                                    <label for="paypal">
                                        <img src="assets/images/paypal.png" alt="PayPal" class="payment-logo">
                                        PayPal
                                    </label>
                                </div>
                                <div class="payment-method">
                                    <input type="radio" id="credit_card" name="payment_method" value="credit_card">
                                    <label for="credit_card">
                                        <img src="assets/images/credit-card.png" alt="Credit Card" class="payment-logo">
                                        Credit Card
                                    </label>
                                </div>
                            </div>
                        </div>
                        
                        <div id="paypal_form" class="payment-details">
                            <p>You will be redirected to PayPal to complete your payment.</p>
                            <p>Click the button below to proceed.</p>
                        </div>
                        
                        <div id="credit_card_form" class="payment-details" style="display: none;">
                            <div class="form-group">
                                <label for="card_number">Card Number</label>
                                <input type="text" id="card_number" name="card_number" placeholder="1234 5678 9012 3456">
                            </div>
                            
                            <div class="form-row">
                                <div class="form-group half">
                                    <label for="expiry_date">Expiry Date</label>
                                    <input type="text" id="expiry_date" name="expiry_date" placeholder="MM/YY">
                                </div>
                                
                                <div class="form-group half">
                                    <label for="cvv">CVV</label>
                                    <input type="text" id="cvv" name="cvv" placeholder="123">
                                </div>
                            </div>
                            
                            <div class="form-group">
                                <label for="card_name">Name on Card</label>
                                <input type="text" id="card_name" name="card_name" placeholder="John Doe">
                            </div>
                        </div>
                        
                        <div class="form-group">
                            <button type="submit" name="process_payment" class="btn btn-primary">Complete Payment</button>
                            <a href="buy_points.php" class="btn">Cancel</a>
                        </div>
                    </form>
                </div>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
    
    <script>
        // Toggle payment method forms
        document.querySelectorAll('input[name="payment_method"]').forEach(function(radio) {
            radio.addEventListener('change', function() {
                document.getElementById('paypal_form').style.display = 'none';
                document.getElementById('credit_card_form').style.display = 'none';
                
                if (this.value === 'paypal') {
                    document.getElementById('paypal_form').style.display = 'block';
                } else if (this.value === 'credit_card') {
                    document.getElementById('credit_card_form').style.display = 'block';
                }
            });
        });
    </script>
</body>
</html>
