<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'models/pyramid.php';
require_once 'models/transaction.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);
$pyramid = new Pyramid($database);
$transaction = new Transaction($database);

// Check if user is logged in
if (!$session->isLoggedIn()) {
    Utils::setFlashMessage('error', 'You must be logged in to access this page.');
    Utils::redirect('login.php');
}

// Get user data
$user_id = $session->getUserId();
$user_data = $user->getUserById($user_id);

if (!$user_data['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve user data.');
    Utils::redirect('dashboard.php');
}

$user_info = $user_data['user'];

// Check if user has points
if ($user_info['points_balance'] <= 0) {
    Utils::setFlashMessage('error', 'You need points to play. Please buy some points first.');
    Utils::redirect('buy_points.php');
}

// Get pyramid ID from query string if provided
$pyramid_id = isset($_GET['pyramid_id']) ? intval($_GET['pyramid_id']) : null;

// If pyramid ID is provided, check if it's valid and active
if ($pyramid_id) {
    $pyramid_data = $pyramid->getPyramidById($pyramid_id);
    if (!$pyramid_data['success'] || $pyramid_data['pyramid']['status'] !== 'active') {
        Utils::setFlashMessage('error', 'Invalid or inactive pyramid.');
        Utils::redirect('pyramids.php');
    }
    $current_pyramid = $pyramid_data['pyramid'];
} else {
    // Get active pyramid
    $active_pyramid = $pyramid->getActivePyramid();
    if (!$active_pyramid['success']) {
        Utils::setFlashMessage('error', 'Failed to retrieve active pyramid.');
        Utils::redirect('dashboard.php');
    }
    $current_pyramid = $active_pyramid['pyramid'];
    $pyramid_id = $current_pyramid['pyramid_id'];
}

// Process play form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['play'])) {
    // Verify CSRF token
    if (!Utils::verifyCsrfToken($_POST['csrf_token'])) {
        Utils::setFlashMessage('error', 'Invalid form submission, please try again.');
        Utils::redirect('play.php');
    }
    
    // Check if user has points
    if ($user_info['points_balance'] <= 0) {
        Utils::setFlashMessage('error', 'You need points to play. Please buy some points first.');
        Utils::redirect('buy_points.php');
    }
    
    // Get next available position
    $position_result = $pyramid->getNextAvailablePosition($pyramid_id);
    if (!$position_result['success']) {
        Utils::setFlashMessage('error', $position_result['message']);
        Utils::redirect('play.php');
    }
    
    $position = $position_result['position'];
    
    // Assign position to user
    $assign_result = $pyramid->assignPosition($user_id, $pyramid_id, $position);
    if (!$assign_result['success']) {
        Utils::setFlashMessage('error', $assign_result['message']);
        Utils::redirect('play.php');
    }
    
    // Deduct point from user's balance
    $update_query = "UPDATE " . $database->table('users') . " 
                    SET points_balance = points_balance - 1 
                    WHERE user_id = :user_id";
    
    $conn = $database->connect();
    $stmt = $conn->prepare($update_query);
    $stmt->bindParam(':user_id', $user_id);
    $stmt->execute();
    
    // Record transaction
    $transaction_query = "INSERT INTO " . $database->table('transactions') . " 
                         (user_id, type, amount, points, status, pyramid_id, position_id, created_at, updated_at) 
                         VALUES (:user_id, 'purchase', :amount, 1, 'completed', :pyramid_id, :position_id, NOW(), NOW())";
    
    $amount = $current_pyramid['point_cost'];
    
    $transaction_stmt = $conn->prepare($transaction_query);
    $transaction_stmt->bindParam(':user_id', $user_id);
    $transaction_stmt->bindParam(':amount', $amount);
    $transaction_stmt->bindParam(':pyramid_id', $pyramid_id);
    $transaction_stmt->bindParam(':position_id', $assign_result['position_id']);
    $transaction_stmt->execute();
    
    // Redirect to pyramid view
    Utils::setFlashMessage('success', 'You have successfully joined the pyramid at position #' . $position['position_number'] . '!');
    Utils::redirect('pyramid_view.php?id=' . $pyramid_id);
}

// Get pyramid visualization
$visualization = $pyramid->getPyramidVisualization($pyramid_id);
if (!$visualization['success']) {
    Utils::setFlashMessage('error', 'Failed to generate pyramid visualization.');
    Utils::redirect('pyramids.php');
}

$levels = $visualization['levels'];

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Play - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
    <style>
        .pyramid-container {
            display: flex;
            flex-direction: column;
            align-items: center;
            margin: 20px 0;
        }
        
        .pyramid-level {
            display: flex;
            justify-content: center;
            margin-bottom: 10px;
        }
        
        .pyramid-position {
            width: 80px;
            height: 80px;
            margin: 0 5px;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            border-radius: 5px;
            font-size: 14px;
            text-align: center;
            position: relative;
        }
        
        .position-zero {
            background-color: #ffd700;
            color: #333;
        }
        
        .position-odd {
            background-color: #ff7f7f;
            color: #333;
        }
        
        .position-even {
            background-color: #7fbfff;
            color: #333;
        }
        
        .position-empty {
            background-color: #f0f0f0;
            color: #999;
            border: 2px dashed #ccc;
        }
        
        .position-number {
            font-weight: bold;
            margin-bottom: 5px;
        }
        
        .position-owner {
            font-size: 12px;
            word-break: break-word;
            max-width: 100%;
            overflow: hidden;
            text-overflow: ellipsis;
        }
        
        .play-info {
            margin-bottom: 20px;
            padding: 15px;
            background-color: #f9f9f9;
            border-radius: 5px;
        }
    </style>
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="dashboard.php">Dashboard</a></li>
                    <li><a href="pyramids.php">Pyramids</a></li>
                    <li><a href="buy_points.php">Buy Points</a></li>
                    <li><a href="profile.php">My Profile</a></li>
                    <li><a href="logout.php">Logout</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section>
                <h2>Play in Pyramid #<?php echo $pyramid_id; ?></h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <div class="play-info">
                    <p><strong>Your Points Balance:</strong> <?php echo $user_info['points_balance']; ?> points</p>
                    <p><strong>Cost to Play:</strong> 1 point ($<?php echo number_format($current_pyramid['point_cost'], 2); ?>)</p>
                    <p><strong>Positions Filled:</strong> <?php echo $current_pyramid['filled_positions']; ?> / <?php echo $current_pyramid['position_count']; ?></p>
                    
                    <div class="play-description">
                        <h3>How to Play</h3>
                        <p>When you play, you will be assigned the next available position in the pyramid.</p>
                        <p>The top position (Zero) is neither odd nor even. The next level contains the first odd and even positions.</p>
                        <p>When the pyramid is full, the owner of the Zero position receives points from the bottom row.</p>
                    </div>
                    
                    <form action="play.php<?php echo $pyramid_id ? '?pyramid_id=' . $pyramid_id : ''; ?>" method="post">
                        <input type="hidden" name="csrf_token" value="<?php echo Utils::generateCsrfToken(); ?>">
                        <button type="submit" name="play" class="btn btn-primary">Play Now (1 Point)</button>
                    </form>
                </div>
                
                <h3>Current Pyramid Status</h3>
                
                <div class="pyramid-container">
                    <?php foreach ($levels as $level => $positions): ?>
                    <div class="pyramid-level">
                        <?php foreach ($positions as $position): ?>
                        <div class="pyramid-position 
                            <?php if (isset($position['empty']) && $position['empty']): ?>
                                position-empty
                            <?php elseif ($position['position_number'] === 0): ?>
                                position-zero
                            <?php elseif ($position['is_odd']): ?>
                                position-odd
                            <?php else: ?>
                                position-even
                            <?php endif; ?>
                        ">
                            <div class="position-number"><?php echo $position['position_number']; ?></div>
                            <?php if (!isset($position['empty']) || !$position['empty']): ?>
                            <div class="position-owner"><?php echo htmlspecialchars($position['nickname']); ?></div>
                            <?php else: ?>
                            <div class="position-owner">Empty</div>
                            <?php endif; ?>
                        </div>
                        <?php endforeach; ?>
                    </div>
                    <?php endforeach; ?>
                </div>
                
                <div class="pyramid-legend">
                    <h3>Legend</h3>
                    <div class="legend-items">
                        <div class="legend-item">
                            <div class="legend-color" style="background-color: #ffd700;"></div>
                            <div class="legend-text">Zero Position (Top)</div>
                        </div>
                        <div class="legend-item">
                            <div class="legend-color" style="background-color: #ff7f7f;"></div>
                            <div class="legend-text">Odd Position</div>
                        </div>
                        <div class="legend-item">
                            <div class="legend-color" style="background-color: #7fbfff;"></div>
                            <div class="legend-text">Even Position</div>
                        </div>
                        <div class="legend-item">
                            <div class="legend-color" style="background-color: #f0f0f0; border: 2px dashed #ccc;"></div>
                            <div class="legend-text">Empty Position</div>
                        </div>
                    </div>
                </div>
                
                <div class="pyramid-actions">
                    <a href="dashboard.php" class="btn">Back to Dashboard</a>
                    <a href="pyramid_view.php?id=<?php echo $pyramid_id; ?>" class="btn">View Full Pyramid</a>
                </div>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
</body>
</html>
