<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);

// Check if user is logged in
if (!$session->isLoggedIn()) {
    Utils::setFlashMessage('error', 'You must be logged in to access this page.');
    Utils::redirect('login.php');
}

// Get user data
$user_id = $session->getUserId();
$user_data = $user->getUserById($user_id);

if (!$user_data['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve user data.');
    Utils::redirect('dashboard.php');
}

$user_info = $user_data['user'];

// Process profile update form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_profile'])) {
    // Verify CSRF token
    if (!Utils::verifyCsrfToken($_POST['csrf_token'])) {
        Utils::setFlashMessage('error', 'Invalid form submission, please try again.');
        Utils::redirect('profile.php');
    }
    
    // Sanitize input
    $nickname = Utils::sanitizeInput($_POST['nickname']);
    $email = Utils::sanitizeInput($_POST['email']);
    
    // Validate input
    $errors = [];
    
    if (empty($nickname)) {
        $errors[] = 'Nickname is required';
    }
    
    if (empty($email)) {
        $errors[] = 'Email is required';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Invalid email format';
    }
    
    // If no errors, update profile
    if (empty($errors)) {
        $result = $user->updateProfile($user_id, $nickname, $email);
        
        if ($result['success']) {
            // Update session nickname if it changed
            if ($nickname !== $session->getNickname()) {
                $_SESSION['nickname'] = $nickname;
            }
            
            Utils::setFlashMessage('success', 'Profile updated successfully.');
            Utils::redirect('profile.php');
        } else {
            Utils::setFlashMessage('error', $result['message']);
        }
    } else {
        // Set error messages
        foreach ($errors as $error) {
            Utils::setFlashMessage('error', $error);
        }
    }
}

// Process password change form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['change_password'])) {
    // Verify CSRF token
    if (!Utils::verifyCsrfToken($_POST['csrf_token'])) {
        Utils::setFlashMessage('error', 'Invalid form submission, please try again.');
        Utils::redirect('profile.php');
    }
    
    // Get input
    $current_password = $_POST['current_password'];
    $new_password = $_POST['new_password'];
    $confirm_password = $_POST['confirm_password'];
    
    // Validate input
    $errors = [];
    
    if (empty($current_password)) {
        $errors[] = 'Current password is required';
    }
    
    if (empty($new_password)) {
        $errors[] = 'New password is required';
    } elseif (strlen($new_password) < 8) {
        $errors[] = 'New password must be at least 8 characters';
    }
    
    if ($new_password !== $confirm_password) {
        $errors[] = 'New passwords do not match';
    }
    
    // If no errors, change password
    if (empty($errors)) {
        $result = $user->changePassword($user_id, $current_password, $new_password);
        
        if ($result['success']) {
            Utils::setFlashMessage('success', 'Password changed successfully.');
            Utils::redirect('profile.php');
        } else {
            Utils::setFlashMessage('error', $result['message']);
        }
    } else {
        // Set error messages
        foreach ($errors as $error) {
            Utils::setFlashMessage('error', $error);
        }
    }
}

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>My Profile - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="dashboard.php">Dashboard</a></li>
                    <li><a href="pyramids.php">Pyramids</a></li>
                    <li><a href="buy_points.php">Buy Points</a></li>
                    <li class="active"><a href="profile.php">My Profile</a></li>
                    <li><a href="logout.php">Logout</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section class="profile-section">
                <h2>My Profile</h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <div class="profile-info">
                    <div class="profile-stats">
                        <div class="stat-box">
                            <h3>Points Balance</h3>
                            <p class="stat-value"><?php echo $user_info['points_balance']; ?></p>
                        </div>
                        <div class="stat-box">
                            <h3>Total Earned</h3>
                            <p class="stat-value"><?php echo $user_info['total_earned']; ?></p>
                        </div>
                        <div class="stat-box">
                            <h3>Total Spent</h3>
                            <p class="stat-value"><?php echo $user_info['total_spent']; ?></p>
                        </div>
                        <div class="stat-box">
                            <h3>Member Since</h3>
                            <p class="stat-value"><?php echo Utils::formatDate($user_info['created_at'], 'M j, Y'); ?></p>
                        </div>
                    </div>
                </div>
                
                <div class="profile-forms">
                    <div class="form-container">
                        <h3>Update Profile</h3>
                        <form action="profile.php" method="post">
                            <input type="hidden" name="csrf_token" value="<?php echo Utils::generateCsrfToken(); ?>">
                            
                            <div class="form-group">
                                <label for="nickname">Nickname</label>
                                <input type="text" id="nickname" name="nickname" value="<?php echo htmlspecialchars($user_info['nickname']); ?>" required>
                            </div>
                            
                            <div class="form-group">
                                <label for="email">Email</label>
                                <input type="email" id="email" name="email" value="<?php echo htmlspecialchars($user_info['email']); ?>" required>
                            </div>
                            
                            <div class="form-group">
                                <button type="submit" name="update_profile" class="btn btn-primary">Update Profile</button>
                            </div>
                        </form>
                    </div>
                    
                    <div class="form-container">
                        <h3>Change Password</h3>
                        <form action="profile.php" method="post">
                            <input type="hidden" name="csrf_token" value="<?php echo Utils::generateCsrfToken(); ?>">
                            
                            <div class="form-group">
                                <label for="current_password">Current Password</label>
                                <input type="password" id="current_password" name="current_password" required>
                            </div>
                            
                            <div class="form-group">
                                <label for="new_password">New Password</label>
                                <input type="password" id="new_password" name="new_password" required>
                                <p class="form-hint">At least 8 characters</p>
                            </div>
                            
                            <div class="form-group">
                                <label for="confirm_password">Confirm New Password</label>
                                <input type="password" id="confirm_password" name="confirm_password" required>
                            </div>
                            
                            <div class="form-group">
                                <button type="submit" name="change_password" class="btn btn-primary">Change Password</button>
                            </div>
                        </form>
                    </div>
                </div>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
    
    <script src="assets/js/script.js"></script>
</body>
</html>
