<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'models/pyramid.php';
require_once 'models/transaction.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);
$pyramid = new Pyramid($database);
$transaction = new Transaction($database);

// Check if user is logged in
if (!$session->isLoggedIn()) {
    Utils::setFlashMessage('error', 'You must be logged in to access this page.');
    Utils::redirect('login.php');
}

// Get user data
$user_id = $session->getUserId();
$user_data = $user->getUserById($user_id);

if (!$user_data['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve user data.');
    Utils::redirect('dashboard.php');
}

$user_info = $user_data['user'];

// Check if pyramid ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    Utils::setFlashMessage('error', 'Invalid pyramid ID.');
    Utils::redirect('pyramids.php');
}

$pyramid_id = intval($_GET['id']);

// Get pyramid data
$pyramid_data = $pyramid->getPyramidById($pyramid_id);
if (!$pyramid_data['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve pyramid data.');
    Utils::redirect('pyramids.php');
}

$pyramid_info = $pyramid_data['pyramid'];

// Get pyramid visualization
$visualization = $pyramid->getPyramidVisualization($pyramid_id);
if (!$visualization['success']) {
    Utils::setFlashMessage('error', 'Failed to generate pyramid visualization.');
    Utils::redirect('pyramids.php');
}

$levels = $visualization['levels'];

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pyramid #<?php echo $pyramid_id; ?> - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
    <style>
        .pyramid-container {
            display: flex;
            flex-direction: column;
            align-items: center;
            margin: 20px 0;
        }
        
        .pyramid-level {
            display: flex;
            justify-content: center;
            margin-bottom: 10px;
        }
        
        .pyramid-position {
            width: 80px;
            height: 80px;
            margin: 0 5px;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            border-radius: 5px;
            font-size: 14px;
            text-align: center;
            position: relative;
        }
        
        .position-zero {
            background-color: #ffd700;
            color: #333;
        }
        
        .position-odd {
            background-color: #ff7f7f;
            color: #333;
        }
        
        .position-even {
            background-color: #7fbfff;
            color: #333;
        }
        
        .position-empty {
            background-color: #f0f0f0;
            color: #999;
            border: 2px dashed #ccc;
        }
        
        .position-number {
            font-weight: bold;
            margin-bottom: 5px;
        }
        
        .position-owner {
            font-size: 12px;
            word-break: break-word;
            max-width: 100%;
            overflow: hidden;
            text-overflow: ellipsis;
        }
        
        .pyramid-info {
            margin-bottom: 20px;
            padding: 15px;
            background-color: #f9f9f9;
            border-radius: 5px;
        }
        
        .pyramid-status {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 14px;
            font-weight: bold;
        }
        
        .status-active {
            background-color: #4caf50;
            color: white;
        }
        
        .status-completed {
            background-color: #2196f3;
            color: white;
        }
    </style>
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="dashboard.php">Dashboard</a></li>
                    <li class="active"><a href="pyramids.php">Pyramids</a></li>
                    <li><a href="buy_points.php">Buy Points</a></li>
                    <li><a href="profile.php">My Profile</a></li>
                    <li><a href="logout.php">Logout</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section>
                <h2>Pyramid #<?php echo $pyramid_id; ?></h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <div class="pyramid-info">
                    <p>
                        <strong>Status:</strong> 
                        <span class="pyramid-status status-<?php echo strtolower($pyramid_info['status']); ?>">
                            <?php echo ucfirst($pyramid_info['status']); ?>
                        </span>
                    </p>
                    <p><strong>Created:</strong> <?php echo Utils::formatDate($pyramid_info['created_at']); ?></p>
                    <p><strong>Positions Filled:</strong> <?php echo $pyramid_info['filled_positions']; ?> / <?php echo $pyramid_info['position_count']; ?></p>
                    <p><strong>Point Cost:</strong> $<?php echo number_format($pyramid_info['point_cost'], 2); ?></p>
                    
                    <?php if ($pyramid_info['status'] === 'completed'): ?>
                    <p><strong>Completed:</strong> <?php echo Utils::formatDate($pyramid_info['completed_at']); ?></p>
                    <p><strong>Zero Position Owner:</strong> <?php echo htmlspecialchars($pyramid_info['zero_position_user']); ?></p>
                    <p><strong>Reward:</strong> <?php echo $pyramid_info['zero_position_reward']; ?> points</p>
                    <?php endif; ?>
                </div>
                
                <div class="pyramid-container">
                    <?php foreach ($levels as $level => $positions): ?>
                    <div class="pyramid-level">
                        <?php foreach ($positions as $position): ?>
                        <div class="pyramid-position 
                            <?php if (isset($position['empty']) && $position['empty']): ?>
                                position-empty
                            <?php elseif ($position['position_number'] === 0): ?>
                                position-zero
                            <?php elseif ($position['is_odd']): ?>
                                position-odd
                            <?php else: ?>
                                position-even
                            <?php endif; ?>
                        ">
                            <div class="position-number"><?php echo $position['position_number']; ?></div>
                            <?php if (!isset($position['empty']) || !$position['empty']): ?>
                            <div class="position-owner"><?php echo htmlspecialchars($position['nickname']); ?></div>
                            <?php else: ?>
                            <div class="position-owner">Empty</div>
                            <?php endif; ?>
                        </div>
                        <?php endforeach; ?>
                    </div>
                    <?php endforeach; ?>
                </div>
                
                <div class="pyramid-legend">
                    <h3>Legend</h3>
                    <div class="legend-items">
                        <div class="legend-item">
                            <div class="legend-color" style="background-color: #ffd700;"></div>
                            <div class="legend-text">Zero Position (Top)</div>
                        </div>
                        <div class="legend-item">
                            <div class="legend-color" style="background-color: #ff7f7f;"></div>
                            <div class="legend-text">Odd Position</div>
                        </div>
                        <div class="legend-item">
                            <div class="legend-color" style="background-color: #7fbfff;"></div>
                            <div class="legend-text">Even Position</div>
                        </div>
                        <div class="legend-item">
                            <div class="legend-color" style="background-color: #f0f0f0; border: 2px dashed #ccc;"></div>
                            <div class="legend-text">Empty Position</div>
                        </div>
                    </div>
                </div>
                
                <div class="pyramid-actions">
                    <a href="pyramids.php" class="btn">Back to Pyramids</a>
                    
                    <?php if ($pyramid_info['status'] === 'active' && $user_info['points_balance'] > 0): ?>
                    <a href="play.php?pyramid_id=<?php echo $pyramid_id; ?>" class="btn btn-primary">Play in this Pyramid</a>
                    <?php elseif ($pyramid_info['status'] === 'active' && $user_info['points_balance'] <= 0): ?>
                    <a href="buy_points.php" class="btn btn-primary">Buy Points to Play</a>
                    <?php endif; ?>
                </div>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
</body>
</html>
