<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'models/pyramid.php';
require_once 'models/transaction.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);
$pyramid = new Pyramid($database);
$transaction = new Transaction($database);

// Check if user is logged in
if (!$session->isLoggedIn()) {
    Utils::setFlashMessage('error', 'You must be logged in to access this page.');
    Utils::redirect('login.php');
}

// Get user data
$user_id = $session->getUserId();
$user_data = $user->getUserById($user_id);

if (!$user_data['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve user data.');
    Utils::redirect('dashboard.php');
}

$user_info = $user_data['user'];

// Get all user pyramids
$user_pyramids = $pyramid->getUserPyramids($user_id, 20);
$user_pyramid_count = $user_pyramids['success'] ? count($user_pyramids['pyramids']) : 0;

// Get all pyramids
$all_pyramids = $pyramid->getAllPyramids(10);
$all_pyramid_count = $all_pyramids['success'] ? count($all_pyramids['pyramids']) : 0;

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pyramids - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="dashboard.php">Dashboard</a></li>
                    <li class="active"><a href="pyramids.php">Pyramids</a></li>
                    <li><a href="buy_points.php">Buy Points</a></li>
                    <li><a href="profile.php">My Profile</a></li>
                    <li><a href="logout.php">Logout</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section>
                <h2>Your Pyramids</h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <?php if ($user_pyramid_count > 0): ?>
                <div class="pyramid-list">
                    <table>
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>Status</th>
                                <th>Positions</th>
                                <th>Created</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($user_pyramids['pyramids'] as $p): ?>
                            <tr>
                                <td>#<?php echo $p['pyramid_id']; ?></td>
                                <td>
                                    <span class="status-badge status-<?php echo strtolower($p['status']); ?>">
                                        <?php echo ucfirst($p['status']); ?>
                                    </span>
                                </td>
                                <td><?php echo $p['filled_positions']; ?> / <?php echo $p['position_count']; ?></td>
                                <td><?php echo Utils::formatDate($p['created_at'], 'M j, Y'); ?></td>
                                <td>
                                    <a href="pyramid_view.php?id=<?php echo $p['pyramid_id']; ?>" class="btn btn-sm">View</a>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                <?php else: ?>
                <div class="empty-state">
                    <p>You haven't joined any pyramids yet.</p>
                    <?php if ($user_info['points_balance'] > 0): ?>
                    <a href="play.php" class="btn btn-primary">Play Now</a>
                    <?php else: ?>
                    <a href="buy_points.php" class="btn btn-primary">Buy Points to Play</a>
                    <?php endif; ?>
                </div>
                <?php endif; ?>
            </section>
            
            <section>
                <h2>Recent Pyramids</h2>
                
                <?php if ($all_pyramid_count > 0): ?>
                <div class="pyramid-list">
                    <table>
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>Status</th>
                                <th>Positions</th>
                                <th>Created</th>
                                <th>Zero Position</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($all_pyramids['pyramids'] as $p): ?>
                            <tr>
                                <td>#<?php echo $p['pyramid_id']; ?></td>
                                <td>
                                    <span class="status-badge status-<?php echo strtolower($p['status']); ?>">
                                        <?php echo ucfirst($p['status']); ?>
                                    </span>
                                </td>
                                <td><?php echo $p['filled_positions']; ?> / <?php echo $p['position_count']; ?></td>
                                <td><?php echo Utils::formatDate($p['created_at'], 'M j, Y'); ?></td>
                                <td>
                                    <?php if ($p['zero_position_user']): ?>
                                    <?php echo htmlspecialchars($p['zero_position_user']); ?>
                                    <?php else: ?>
                                    <em>Not assigned</em>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <a href="pyramid_view.php?id=<?php echo $p['pyramid_id']; ?>" class="btn btn-sm">View</a>
                                    <?php if ($p['status'] === 'active' && $user_info['points_balance'] > 0): ?>
                                    <a href="play.php?pyramid_id=<?php echo $p['pyramid_id']; ?>" class="btn btn-sm btn-primary">Play</a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                <?php else: ?>
                <div class="empty-state">
                    <p>No pyramids have been created yet.</p>
                </div>
                <?php endif; ?>
            </section>
            
            <section class="pyramid-info-box">
                <h3>How Pyramids Work</h3>
                <div class="info-content">
                    <p>Each pyramid has a "Zero" position at the top, which is neither odd nor even.</p>
                    <p>Below the Zero position are the first odd and even positions.</p>
                    <p>Each level doubles the number of positions: 1, 2, 4, 8, etc.</p>
                    <p>When all positions in a pyramid are filled, the Zero position owner receives points from the bottom row.</p>
                    <p>The more positions in the bottom row, the more points the Zero position owner receives.</p>
                </div>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
</body>
</html>
