<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);

// Check if token is provided
if (!isset($_GET['token']) || empty($_GET['token'])) {
    Utils::setFlashMessage('error', 'Invalid password reset token.');
    Utils::redirect('login.php');
}

$token = $_GET['token'];

// Verify token
$token_result = $user->verifyResetToken($token);
if (!$token_result['success']) {
    Utils::setFlashMessage('error', 'Invalid or expired password reset token. Please request a new one.');
    Utils::redirect('forgot_password.php');
}

// Process reset password form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['reset_password'])) {
    // Verify CSRF token
    if (!Utils::verifyCsrfToken($_POST['csrf_token'])) {
        Utils::setFlashMessage('error', 'Invalid form submission, please try again.');
        Utils::redirect('reset_password.php?token=' . $token);
    }
    
    // Get input
    $password = $_POST['password'];
    $confirm_password = $_POST['confirm_password'];
    
    // Validate input
    $errors = [];
    
    if (empty($password)) {
        $errors[] = 'Password is required';
    } elseif (strlen($password) < 8) {
        $errors[] = 'Password must be at least 8 characters';
    }
    
    if ($password !== $confirm_password) {
        $errors[] = 'Passwords do not match';
    }
    
    // If no errors, reset password
    if (empty($errors)) {
        $result = $user->resetPassword($token, $password);
        
        if ($result['success']) {
            Utils::setFlashMessage('success', 'Your password has been reset successfully. You can now log in with your new password.');
            Utils::redirect('login.php');
        } else {
            Utils::setFlashMessage('error', $result['message']);
        }
    } else {
        // Set error messages
        foreach ($errors as $error) {
            Utils::setFlashMessage('error', $error);
        }
    }
}

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reset Password - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="index.php">Home</a></li>
                    <li><a href="login.php">Login</a></li>
                    <li><a href="register.php">Register</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section class="auth-form">
                <h2>Reset Password</h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <form action="reset_password.php?token=<?php echo htmlspecialchars($token); ?>" method="post">
                    <input type="hidden" name="csrf_token" value="<?php echo Utils::generateCsrfToken(); ?>">
                    
                    <div class="form-group">
                        <label for="password">New Password</label>
                        <input type="password" id="password" name="password" required>
                        <p class="form-hint">At least 8 characters</p>
                    </div>
                    
                    <div class="form-group">
                        <label for="confirm_password">Confirm New Password</label>
                        <input type="password" id="confirm_password" name="confirm_password" required>
                    </div>
                    
                    <div class="form-group">
                        <button type="submit" name="reset_password" class="btn btn-primary">Reset Password</button>
                    </div>
                    
                    <p class="form-footer">
                        <a href="login.php">Back to Login</a>
                    </p>
                </form>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
    
    <script src="assets/js/script.js"></script>
</body>
</html>
