<?php
// Include required files
require_once 'config/config.php';
require_once 'config/database.php';
require_once 'models/user.php';
require_once 'models/session.php';
require_once 'models/transaction.php';
require_once 'utils/utils.php';

// Initialize database connection
$database = new Database(DB_HOST, DB_NAME, DB_USER, DB_PASS, DB_PREFIX);
$user = new User($database);
$session = new Session($database);
$transaction = new Transaction($database);

// Check if user is logged in
if (!$session->isLoggedIn()) {
    Utils::setFlashMessage('error', 'You must be logged in to access this page.');
    Utils::redirect('login.php');
}

// Get user data
$user_id = $session->getUserId();
$user_data = $user->getUserById($user_id);

if (!$user_data['success']) {
    Utils::setFlashMessage('error', 'Failed to retrieve user data.');
    Utils::redirect('dashboard.php');
}

$user_info = $user_data['user'];

// Get user transactions
$user_transactions = $transaction->getUserTransactions($user_id, 20);
$transaction_count = $user_transactions['success'] ? count($user_transactions['transactions']) : 0;

// Process cashout form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['cashout'])) {
    // Verify CSRF token
    if (!Utils::verifyCsrfToken($_POST['csrf_token'])) {
        Utils::setFlashMessage('error', 'Invalid form submission, please try again.');
        Utils::redirect('transactions.php');
    }
    
    // Get input
    $points = intval($_POST['points']);
    
    // Validate input
    if ($points <= 0) {
        Utils::setFlashMessage('error', 'Please enter a valid number of points.');
    } elseif ($points > $user_info['points_balance']) {
        Utils::setFlashMessage('error', 'You do not have enough points for this cashout.');
    } else {
        // Create cashout transaction
        $cashout_result = $transaction->createCashout($user_id, $points);
        
        if ($cashout_result['success']) {
            // In a real application, this would trigger a payment process
            // For this demo, we'll just complete the cashout immediately
            $reference_id = 'CASHOUT_' . strtoupper(Utils::generateRandomString(8));
            $complete_result = $transaction->completeCashout($cashout_result['transaction_id'], $reference_id);
            
            if ($complete_result['success']) {
                Utils::setFlashMessage('success', 'Cashout processed successfully! $' . number_format($points, 2) . ' will be sent to your account.');
            } else {
                Utils::setFlashMessage('error', $complete_result['message']);
            }
        } else {
            Utils::setFlashMessage('error', $cashout_result['message']);
        }
    }
    
    Utils::redirect('transactions.php');
}

// Get flash messages
$flash = Utils::getFlashMessage();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Transactions - Points Club</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <header>
            <h1>Points Club</h1>
            <nav>
                <ul>
                    <li><a href="dashboard.php">Dashboard</a></li>
                    <li><a href="pyramids.php">Pyramids</a></li>
                    <li><a href="buy_points.php">Buy Points</a></li>
                    <li class="active"><a href="transactions.php">Transactions</a></li>
                    <li><a href="profile.php">My Profile</a></li>
                    <li><a href="logout.php">Logout</a></li>
                </ul>
            </nav>
        </header>
        
        <main>
            <section class="transactions-section">
                <h2>Your Transactions</h2>
                
                <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
                <?php endif; ?>
                
                <div class="balance-box">
                    <div class="balance-info">
                        <h3>Current Balance</h3>
                        <p class="balance-amount"><?php echo $user_info['points_balance']; ?> points</p>
                    </div>
                    
                    <div class="balance-actions">
                        <a href="buy_points.php" class="btn">Buy Points</a>
                        
                        <?php if ($user_info['points_balance'] > 0): ?>
                        <button id="cashout-btn" class="btn btn-primary">Cash Out</button>
                        <?php endif; ?>
                    </div>
                </div>
                
                <div id="cashout-form" class="cashout-form" style="display: none;">
                    <h3>Cash Out Points</h3>
                    <form action="transactions.php" method="post">
                        <input type="hidden" name="csrf_token" value="<?php echo Utils::generateCsrfToken(); ?>">
                        
                        <div class="form-group">
                            <label for="points">Number of Points to Cash Out</label>
                            <input type="number" id="points" name="points" min="1" max="<?php echo $user_info['points_balance']; ?>" value="1" required>
                            <p class="form-hint">1 point = $1.00</p>
                        </div>
                        
                        <div class="form-group">
                            <label for="total">Total Amount</label>
                            <div class="total-display">$<span id="total-amount">1.00</span></div>
                        </div>
                        
                        <div class="form-group">
                            <button type="submit" name="cashout" class="btn btn-primary">Process Cashout</button>
                            <button type="button" id="cancel-cashout" class="btn">Cancel</button>
                        </div>
                    </form>
                </div>
                
                <?php if ($transaction_count > 0): ?>
                <div class="transaction-list">
                    <h3>Transaction History</h3>
                    <table>
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>Type</th>
                                <th>Amount</th>
                                <th>Points</th>
                                <th>Status</th>
                                <th>Date</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($user_transactions['transactions'] as $t): ?>
                            <tr>
                                <td>#<?php echo $t['transaction_id']; ?></td>
                                <td>
                                    <span class="transaction-type type-<?php echo strtolower($t['type']); ?>">
                                        <?php echo ucfirst($t['type']); ?>
                                    </span>
                                </td>
                                <td>$<?php echo number_format($t['amount'], 2); ?></td>
                                <td><?php echo $t['points']; ?></td>
                                <td>
                                    <span class="status-badge status-<?php echo strtolower($t['status']); ?>">
                                        <?php echo ucfirst($t['status']); ?>
                                    </span>
                                </td>
                                <td><?php echo Utils::formatDate($t['created_at']); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                <?php else: ?>
                <div class="empty-state">
                    <p>You don't have any transactions yet.</p>
                    <a href="buy_points.php" class="btn btn-primary">Buy Points</a>
                </div>
                <?php endif; ?>
            </section>
        </main>
        
        <footer>
            <p>&copy; <?php echo date('Y'); ?> Points Club. All rights reserved.</p>
        </footer>
    </div>
    
    <script>
        // Toggle cashout form
        document.getElementById('cashout-btn').addEventListener('click', function() {
            document.getElementById('cashout-form').style.display = 'block';
        });
        
        document.getElementById('cancel-cashout').addEventListener('click', function() {
            document.getElementById('cashout-form').style.display = 'none';
        });
        
        // Calculate total amount based on points
        document.getElementById('points').addEventListener('input', function() {
            const points = parseInt(this.value) || 0;
            const total = points.toFixed(2);
            document.getElementById('total-amount').textContent = total;
        });
    </script>
</body>
</html>
